# This file is auto-generated by AWSMetadata.jl
using AWS
using AWS.AWSServices: organizations
using AWS.Compat
using AWS.UUIDs

"""
    accept_handshake(handshake_id)
    accept_handshake(handshake_id, params::Dict{String,<:Any})

Sends a response to the originator of a handshake agreeing to the action proposed by the
handshake request. This operation can be called only by the following principals when they
also have the relevant IAM permissions:    Invitation to join or Approve all features
request handshakes: only a principal from the member account. The user who calls the API
for an invitation to join must have the organizations:AcceptHandshake permission. If you
enabled all features in the organization, the user must also have the
iam:CreateServiceLinkedRole permission so that AWS Organizations can create the required
service-linked role named AWSServiceRoleForOrganizations. For more information, see AWS
Organizations and Service-Linked Roles in the AWS Organizations User Guide.    Enable all
features final confirmation handshake: only a principal from the management account. For
more information about invitations, see Inviting an AWS Account to Join Your Organization
in the AWS Organizations User Guide. For more information about requests to enable all
features in the organization, see Enabling All Features in Your Organization in the AWS
Organizations User Guide.    After you accept a handshake, it continues to appear in the
results of relevant APIs for only 30 days. After that, it's deleted.

# Arguments
- `handshake_id`: The unique identifier (ID) of the handshake that you want to accept. The
  regex pattern for handshake ID string requires \"h-\" followed by from 8 to 32 lowercase
  letters or digits.

"""
accept_handshake(HandshakeId; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("AcceptHandshake", Dict{String, Any}("HandshakeId"=>HandshakeId); aws_config=aws_config)
accept_handshake(HandshakeId, params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("AcceptHandshake", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("HandshakeId"=>HandshakeId), params)); aws_config=aws_config)

"""
    attach_policy(policy_id, target_id)
    attach_policy(policy_id, target_id, params::Dict{String,<:Any})

Attaches a policy to a root, an organizational unit (OU), or an individual account. How the
policy affects accounts depends on the type of policy. Refer to the AWS Organizations User
Guide for information about each policy type:    AISERVICES_OPT_OUT_POLICY
BACKUP_POLICY     SERVICE_CONTROL_POLICY     TAG_POLICY    This operation can be called
only from the organization's management account.

# Arguments
- `policy_id`: The unique identifier (ID) of the policy that you want to attach to the
  target. You can get the ID for the policy by calling the ListPolicies operation. The regex
  pattern for a policy ID string requires \"p-\" followed by from 8 to 128 lowercase or
  uppercase letters, digits, or the underscore character (_).
- `target_id`: The unique identifier (ID) of the root, OU, or account that you want to
  attach the policy to. You can get the ID by calling the ListRoots,
  ListOrganizationalUnitsForParent, or ListAccounts operations. The regex pattern for a
  target ID string requires one of the following:    Root - A string that begins with \"r-\"
  followed by from 4 to 32 lowercase letters or digits.    Account - A string that consists
  of exactly 12 digits.    Organizational unit (OU) - A string that begins with \"ou-\"
  followed by from 4 to 32 lowercase letters or digits (the ID of the root that the OU is
  in). This string is followed by a second \"-\" dash and from 8 to 32 additional lowercase
  letters or digits.

"""
attach_policy(PolicyId, TargetId; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("AttachPolicy", Dict{String, Any}("PolicyId"=>PolicyId, "TargetId"=>TargetId); aws_config=aws_config)
attach_policy(PolicyId, TargetId, params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("AttachPolicy", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("PolicyId"=>PolicyId, "TargetId"=>TargetId), params)); aws_config=aws_config)

"""
    cancel_handshake(handshake_id)
    cancel_handshake(handshake_id, params::Dict{String,<:Any})

Cancels a handshake. Canceling a handshake sets the handshake state to CANCELED. This
operation can be called only from the account that originated the handshake. The recipient
of the handshake can't cancel it, but can use DeclineHandshake instead. After a handshake
is canceled, the recipient can no longer respond to that handshake. After you cancel a
handshake, it continues to appear in the results of relevant APIs for only 30 days. After
that, it's deleted.

# Arguments
- `handshake_id`: The unique identifier (ID) of the handshake that you want to cancel. You
  can get the ID from the ListHandshakesForOrganization operation. The regex pattern for
  handshake ID string requires \"h-\" followed by from 8 to 32 lowercase letters or digits.

"""
cancel_handshake(HandshakeId; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("CancelHandshake", Dict{String, Any}("HandshakeId"=>HandshakeId); aws_config=aws_config)
cancel_handshake(HandshakeId, params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("CancelHandshake", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("HandshakeId"=>HandshakeId), params)); aws_config=aws_config)

"""
    create_account(account_name, email)
    create_account(account_name, email, params::Dict{String,<:Any})

Creates an AWS account that is automatically a member of the organization whose credentials
made the request. This is an asynchronous request that AWS performs in the background.
Because CreateAccount operates asynchronously, it can return a successful completion
message even though account initialization might still be in progress. You might need to
wait a few minutes before you can successfully access the account. To check the status of
the request, do one of the following:   Use the Id member of the CreateAccountStatus
response element from this operation to provide as a parameter to the
DescribeCreateAccountStatus operation.   Check the AWS CloudTrail log for the
CreateAccountResult event. For information on using AWS CloudTrail with AWS Organizations,
see Logging and monitoring in AWS Organizations in the AWS Organizations User Guide.    The
user who calls the API to create an account must have the organizations:CreateAccount
permission. If you enabled all features in the organization, AWS Organizations creates the
required service-linked role named AWSServiceRoleForOrganizations. For more information,
see AWS Organizations and Service-Linked Roles in the AWS Organizations User Guide. If the
request includes tags, then the requester must have the organizations:TagResource
permission. AWS Organizations preconfigures the new member account with a role (named
OrganizationAccountAccessRole by default) that grants users in the management account
administrator permissions in the new member account. Principals in the management account
can assume the role. AWS Organizations clones the company name and address information for
the new account from the organization's management account. This operation can be called
only from the organization's management account. For more information about creating
accounts, see Creating an AWS Account in Your Organization in the AWS Organizations User
Guide.     When you create an account in an organization using the AWS Organizations
console, API, or CLI commands, the information required for the account to operate as a
standalone account, such as a payment method and signing the end user license agreement
(EULA) is not automatically collected. If you must remove an account from your organization
later, you can do so only after you provide the missing information. Follow the steps at
To leave an organization as a member account in the AWS Organizations User Guide.   If you
get an exception that indicates that you exceeded your account limits for the organization,
contact AWS Support.   If you get an exception that indicates that the operation failed
because your organization is still initializing, wait one hour and then try again. If the
error persists, contact AWS Support.   Using CreateAccount to create multiple temporary
accounts isn't recommended. You can only close an account from the Billing and Cost
Management Console, and you must be signed in as the root user. For information on the
requirements and process for closing an account, see Closing an AWS Account in the AWS
Organizations User Guide.     When you create a member account with this operation, you can
choose whether to create the account with the IAM User and Role Access to Billing
Information switch enabled. If you enable it, IAM users and roles that have appropriate
permissions can view billing information for the account. If you disable it, only the
account root user can access billing information. For information about how to disable this
switch for an account, see Granting Access to Your Billing Information and Tools.

# Arguments
- `account_name`: The friendly name of the member account.
- `email`: The email address of the owner to assign to the new member account. This email
  address must not already be associated with another AWS account. You must use a valid email
  address to complete account creation. You can't access the root user of the account or
  remove an account that was created with an invalid email address.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"IamUserAccessToBilling"`: If set to ALLOW, the new account enables IAM users to access
  account billing information if they have the required permissions. If set to DENY, only the
  root user of the new account can access account billing information. For more information,
  see Activating Access to the Billing and Cost Management Console in the AWS Billing and
  Cost Management User Guide. If you don't specify this parameter, the value defaults to
  ALLOW, and IAM users and roles with the required permissions can access billing information
  for the new account.
- `"RoleName"`: (Optional) The name of an IAM role that AWS Organizations automatically
  preconfigures in the new member account. This role trusts the management account, allowing
  users in the management account to assume the role, as permitted by the management account
  administrator. The role has administrator permissions in the new member account. If you
  don't specify this parameter, the role name defaults to OrganizationAccountAccessRole. For
  more information about how to use this role to access the member account, see the following
  links:    Accessing and Administering the Member Accounts in Your Organization in the AWS
  Organizations User Guide    Steps 2 and 3 in Tutorial: Delegate Access Across AWS Accounts
  Using IAM Roles in the IAM User Guide    The regex pattern that is used to validate this
  parameter. The pattern can include uppercase letters, lowercase letters, digits with no
  spaces, and any of the following characters: =,.@-
- `"Tags"`: A list of tags that you want to attach to the newly created account. For each
  tag in the list, you must specify both a tag key and a value. You can set the value to an
  empty string, but you can't set it to null. For more information about tagging, see Tagging
  AWS Organizations resources in the AWS Organizations User Guide.  If any one of the tags is
  invalid or if you exceed the allowed number of tags for an account, then the entire request
  fails and the account is not created.
"""
create_account(AccountName, Email; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("CreateAccount", Dict{String, Any}("AccountName"=>AccountName, "Email"=>Email); aws_config=aws_config)
create_account(AccountName, Email, params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("CreateAccount", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("AccountName"=>AccountName, "Email"=>Email), params)); aws_config=aws_config)

"""
    create_gov_cloud_account(account_name, email)
    create_gov_cloud_account(account_name, email, params::Dict{String,<:Any})

This action is available if all of the following are true:   You're authorized to create
accounts in the AWS GovCloud (US) Region. For more information on the AWS GovCloud (US)
Region, see the  AWS GovCloud User Guide.    You already have an account in the AWS
GovCloud (US) Region that is paired with a management account of an organization in the
commercial Region.   You call this action from the management account of your organization
in the commercial Region.   You have the organizations:CreateGovCloudAccount permission.
AWS Organizations automatically creates the required service-linked role named
AWSServiceRoleForOrganizations. For more information, see AWS Organizations and
Service-Linked Roles in the AWS Organizations User Guide.  AWS automatically enables AWS
CloudTrail for AWS GovCloud (US) accounts, but you should also do the following:   Verify
that AWS CloudTrail is enabled to store logs.   Create an S3 bucket for AWS CloudTrail log
storage. For more information, see Verifying AWS CloudTrail Is Enabled in the AWS GovCloud
User Guide.    If the request includes tags, then the requester must have the
organizations:TagResource permission. The tags are attached to the commercial account
associated with the GovCloud account, rather than the GovCloud account itself. To add tags
to the GovCloud account, call the TagResource operation in the GovCloud Region after the
new GovCloud account exists. You call this action from the management account of your
organization in the commercial Region to create a standalone AWS account in the AWS
GovCloud (US) Region. After the account is created, the management account of an
organization in the AWS GovCloud (US) Region can invite it to that organization. For more
information on inviting standalone accounts in the AWS GovCloud (US) to join an
organization, see AWS Organizations in the AWS GovCloud User Guide.  Calling
CreateGovCloudAccount is an asynchronous request that AWS performs in the background.
Because CreateGovCloudAccount operates asynchronously, it can return a successful
completion message even though account initialization might still be in progress. You might
need to wait a few minutes before you can successfully access the account. To check the
status of the request, do one of the following:   Use the OperationId response element from
this operation to provide as a parameter to the DescribeCreateAccountStatus operation.
Check the AWS CloudTrail log for the CreateAccountResult event. For information on using
AWS CloudTrail with Organizations, see Monitoring the Activity in Your Organization in the
AWS Organizations User Guide.     When you call the CreateGovCloudAccount action, you
create two accounts: a standalone account in the AWS GovCloud (US) Region and an associated
account in the commercial Region for billing and support purposes. The account in the
commercial Region is automatically a member of the organization whose credentials made the
request. Both accounts are associated with the same email address. A role is created in the
new account in the commercial Region that allows the management account in the organization
in the commercial Region to assume it. An AWS GovCloud (US) account is then created and
associated with the commercial account that you just created. A role is also created in the
new AWS GovCloud (US) account that can be assumed by the AWS GovCloud (US) account that is
associated with the management account of the commercial organization. For more information
and to view a diagram that explains how account access works, see AWS Organizations in the
AWS GovCloud User Guide.  For more information about creating accounts, see Creating an AWS
Account in Your Organization in the AWS Organizations User Guide.     When you create an
account in an organization using the AWS Organizations console, API, or CLI commands, the
information required for the account to operate as a standalone account is not
automatically collected. This includes a payment method and signing the end user license
agreement (EULA). If you must remove an account from your organization later, you can do so
only after you provide the missing information. Follow the steps at  To leave an
organization as a member account in the AWS Organizations User Guide.    If you get an
exception that indicates that you exceeded your account limits for the organization,
contact AWS Support.   If you get an exception that indicates that the operation failed
because your organization is still initializing, wait one hour and then try again. If the
error persists, contact AWS Support.   Using CreateGovCloudAccount to create multiple
temporary accounts isn't recommended. You can only close an account from the AWS Billing
and Cost Management console, and you must be signed in as the root user. For information on
the requirements and process for closing an account, see Closing an AWS Account in the AWS
Organizations User Guide.     When you create a member account with this operation, you can
choose whether to create the account with the IAM User and Role Access to Billing
Information switch enabled. If you enable it, IAM users and roles that have appropriate
permissions can view billing information for the account. If you disable it, only the
account root user can access billing information. For information about how to disable this
switch for an account, see Granting Access to Your Billing Information and Tools.

# Arguments
- `account_name`: The friendly name of the member account.
- `email`: The email address of the owner to assign to the new member account in the
  commercial Region. This email address must not already be associated with another AWS
  account. You must use a valid email address to complete account creation. You can't access
  the root user of the account or remove an account that was created with an invalid email
  address. Like all request parameters for CreateGovCloudAccount, the request for the email
  address for the AWS GovCloud (US) account originates from the commercial Region, not from
  the AWS GovCloud (US) Region.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"IamUserAccessToBilling"`: If set to ALLOW, the new linked account in the commercial
  Region enables IAM users to access account billing information if they have the required
  permissions. If set to DENY, only the root user of the new account can access account
  billing information. For more information, see Activating Access to the Billing and Cost
  Management Console in the AWS Billing and Cost Management User Guide.  If you don't specify
  this parameter, the value defaults to ALLOW, and IAM users and roles with the required
  permissions can access billing information for the new account.
- `"RoleName"`: (Optional) The name of an IAM role that AWS Organizations automatically
  preconfigures in the new member accounts in both the AWS GovCloud (US) Region and in the
  commercial Region. This role trusts the management account, allowing users in the
  management account to assume the role, as permitted by the management account
  administrator. The role has administrator permissions in the new member account. If you
  don't specify this parameter, the role name defaults to OrganizationAccountAccessRole. For
  more information about how to use this role to access the member account, see Accessing and
  Administering the Member Accounts in Your Organization in the AWS Organizations User Guide
  and steps 2 and 3 in Tutorial: Delegate Access Across AWS Accounts Using IAM Roles in the
  IAM User Guide.  The regex pattern that is used to validate this parameter. The pattern can
  include uppercase letters, lowercase letters, digits with no spaces, and any of the
  following characters: =,.@-
- `"Tags"`: A list of tags that you want to attach to the newly created account. These tags
  are attached to the commercial account associated with the GovCloud account, and not to the
  GovCloud account itself. To add tags to the actual GovCloud account, call the TagResource
  operation in the GovCloud region after the new GovCloud account exists. For each tag in the
  list, you must specify both a tag key and a value. You can set the value to an empty
  string, but you can't set it to null. For more information about tagging, see Tagging AWS
  Organizations resources in the AWS Organizations User Guide.  If any one of the tags is
  invalid or if you exceed the allowed number of tags for an account, then the entire request
  fails and the account is not created.
"""
create_gov_cloud_account(AccountName, Email; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("CreateGovCloudAccount", Dict{String, Any}("AccountName"=>AccountName, "Email"=>Email); aws_config=aws_config)
create_gov_cloud_account(AccountName, Email, params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("CreateGovCloudAccount", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("AccountName"=>AccountName, "Email"=>Email), params)); aws_config=aws_config)

"""
    create_organization()
    create_organization(params::Dict{String,<:Any})

Creates an AWS organization. The account whose user is calling the CreateOrganization
operation automatically becomes the management account of the new organization. This
operation must be called using credentials from the account that is to become the new
organization's management account. The principal must also have the relevant IAM
permissions. By default (or if you set the FeatureSet parameter to ALL), the new
organization is created with all features enabled and service control policies
automatically enabled in the root. If you instead choose to create the organization
supporting only the consolidated billing features by setting the FeatureSet parameter to
CONSOLIDATED_BILLING\", no policy types are enabled by default, and you can't use
organization policies

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"FeatureSet"`: Specifies the feature set supported by the new organization. Each feature
  set supports different levels of functionality.    CONSOLIDATED_BILLING: All member
  accounts have their bills consolidated to and paid by the management account. For more
  information, see Consolidated billing in the AWS Organizations User Guide.   The
  consolidated billing feature subset isn't available for organizations in the AWS GovCloud
  (US) Region.    ALL: In addition to all the features supported by the consolidated billing
  feature set, the management account can also apply any policy type to any member account in
  the organization. For more information, see All features in the AWS Organizations User
  Guide.
"""
create_organization(; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("CreateOrganization"; aws_config=aws_config)
create_organization(params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("CreateOrganization", params; aws_config=aws_config)

"""
    create_organizational_unit(name, parent_id)
    create_organizational_unit(name, parent_id, params::Dict{String,<:Any})

Creates an organizational unit (OU) within a root or parent OU. An OU is a container for
accounts that enables you to organize your accounts to apply policies according to your
business requirements. The number of levels deep that you can nest OUs is dependent upon
the policy types enabled for that root. For service control policies, the limit is five.
For more information about OUs, see Managing Organizational Units in the AWS Organizations
User Guide.  If the request includes tags, then the requester must have the
organizations:TagResource permission. This operation can be called only from the
organization's management account.

# Arguments
- `name`: The friendly name to assign to the new OU.
- `parent_id`: The unique identifier (ID) of the parent root or OU that you want to create
  the new OU in. The regex pattern for a parent ID string requires one of the following:
  Root - A string that begins with \"r-\" followed by from 4 to 32 lowercase letters or
  digits.    Organizational unit (OU) - A string that begins with \"ou-\" followed by from 4
  to 32 lowercase letters or digits (the ID of the root that the OU is in). This string is
  followed by a second \"-\" dash and from 8 to 32 additional lowercase letters or digits.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"Tags"`: A list of tags that you want to attach to the newly created OU. For each tag in
  the list, you must specify both a tag key and a value. You can set the value to an empty
  string, but you can't set it to null. For more information about tagging, see Tagging AWS
  Organizations resources in the AWS Organizations User Guide.  If any one of the tags is
  invalid or if you exceed the allowed number of tags for an OU, then the entire request
  fails and the OU is not created.
"""
create_organizational_unit(Name, ParentId; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("CreateOrganizationalUnit", Dict{String, Any}("Name"=>Name, "ParentId"=>ParentId); aws_config=aws_config)
create_organizational_unit(Name, ParentId, params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("CreateOrganizationalUnit", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("Name"=>Name, "ParentId"=>ParentId), params)); aws_config=aws_config)

"""
    create_policy(content, description, name, type)
    create_policy(content, description, name, type, params::Dict{String,<:Any})

Creates a policy of a specified type that you can attach to a root, an organizational unit
(OU), or an individual AWS account. For more information about policies and their use, see
Managing Organization Policies. If the request includes tags, then the requester must have
the organizations:TagResource permission. This operation can be called only from the
organization's management account.

# Arguments
- `content`: The policy text content to add to the new policy. The text that you supply
  must adhere to the rules of the policy type you specify in the Type parameter.
- `description`: An optional description to assign to the policy.
- `name`: The friendly name to assign to the policy. The regex pattern that is used to
  validate this parameter is a string of any of the characters in the ASCII character range.
- `type`: The type of policy to create. You can specify one of the following values:
  AISERVICES_OPT_OUT_POLICY     BACKUP_POLICY     SERVICE_CONTROL_POLICY     TAG_POLICY

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"Tags"`: A list of tags that you want to attach to the newly created policy. For each
  tag in the list, you must specify both a tag key and a value. You can set the value to an
  empty string, but you can't set it to null. For more information about tagging, see Tagging
  AWS Organizations resources in the AWS Organizations User Guide.  If any one of the tags is
  invalid or if you exceed the allowed number of tags for a policy, then the entire request
  fails and the policy is not created.
"""
create_policy(Content, Description, Name, Type; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("CreatePolicy", Dict{String, Any}("Content"=>Content, "Description"=>Description, "Name"=>Name, "Type"=>Type); aws_config=aws_config)
create_policy(Content, Description, Name, Type, params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("CreatePolicy", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("Content"=>Content, "Description"=>Description, "Name"=>Name, "Type"=>Type), params)); aws_config=aws_config)

"""
    decline_handshake(handshake_id)
    decline_handshake(handshake_id, params::Dict{String,<:Any})

Declines a handshake request. This sets the handshake state to DECLINED and effectively
deactivates the request. This operation can be called only from the account that received
the handshake. The originator of the handshake can use CancelHandshake instead. The
originator can't reactivate a declined request, but can reinitiate the process with a new
handshake request. After you decline a handshake, it continues to appear in the results of
relevant APIs for only 30 days. After that, it's deleted.

# Arguments
- `handshake_id`: The unique identifier (ID) of the handshake that you want to decline. You
  can get the ID from the ListHandshakesForAccount operation. The regex pattern for handshake
  ID string requires \"h-\" followed by from 8 to 32 lowercase letters or digits.

"""
decline_handshake(HandshakeId; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("DeclineHandshake", Dict{String, Any}("HandshakeId"=>HandshakeId); aws_config=aws_config)
decline_handshake(HandshakeId, params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("DeclineHandshake", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("HandshakeId"=>HandshakeId), params)); aws_config=aws_config)

"""
    delete_organization()
    delete_organization(params::Dict{String,<:Any})

Deletes the organization. You can delete an organization only by using credentials from the
management account. The organization must be empty of member accounts.

"""
delete_organization(; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("DeleteOrganization"; aws_config=aws_config)
delete_organization(params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("DeleteOrganization", params; aws_config=aws_config)

"""
    delete_organizational_unit(organizational_unit_id)
    delete_organizational_unit(organizational_unit_id, params::Dict{String,<:Any})

Deletes an organizational unit (OU) from a root or another OU. You must first remove all
accounts and child OUs from the OU that you want to delete. This operation can be called
only from the organization's management account.

# Arguments
- `organizational_unit_id`: The unique identifier (ID) of the organizational unit that you
  want to delete. You can get the ID from the ListOrganizationalUnitsForParent operation. The
  regex pattern for an organizational unit ID string requires \"ou-\" followed by from 4 to
  32 lowercase letters or digits (the ID of the root that contains the OU). This string is
  followed by a second \"-\" dash and from 8 to 32 additional lowercase letters or digits.

"""
delete_organizational_unit(OrganizationalUnitId; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("DeleteOrganizationalUnit", Dict{String, Any}("OrganizationalUnitId"=>OrganizationalUnitId); aws_config=aws_config)
delete_organizational_unit(OrganizationalUnitId, params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("DeleteOrganizationalUnit", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("OrganizationalUnitId"=>OrganizationalUnitId), params)); aws_config=aws_config)

"""
    delete_policy(policy_id)
    delete_policy(policy_id, params::Dict{String,<:Any})

Deletes the specified policy from your organization. Before you perform this operation, you
must first detach the policy from all organizational units (OUs), roots, and accounts. This
operation can be called only from the organization's management account.

# Arguments
- `policy_id`: The unique identifier (ID) of the policy that you want to delete. You can
  get the ID from the ListPolicies or ListPoliciesForTarget operations. The regex pattern for
  a policy ID string requires \"p-\" followed by from 8 to 128 lowercase or uppercase
  letters, digits, or the underscore character (_).

"""
delete_policy(PolicyId; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("DeletePolicy", Dict{String, Any}("PolicyId"=>PolicyId); aws_config=aws_config)
delete_policy(PolicyId, params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("DeletePolicy", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("PolicyId"=>PolicyId), params)); aws_config=aws_config)

"""
    deregister_delegated_administrator(account_id, service_principal)
    deregister_delegated_administrator(account_id, service_principal, params::Dict{String,<:Any})

Removes the specified member AWS account as a delegated administrator for the specified AWS
service.  Deregistering a delegated administrator can have unintended impacts on the
functionality of the enabled AWS service. See the documentation for the enabled service
before you deregister a delegated administrator so that you understand any potential
impacts.  You can run this action only for AWS services that support this feature. For a
current list of services that support it, see the column Supports Delegated Administrator
in the table at AWS Services that you can use with AWS Organizations in the AWS
Organizations User Guide.  This operation can be called only from the organization's
management account.

# Arguments
- `account_id`: The account ID number of the member account in the organization that you
  want to deregister as a delegated administrator.
- `service_principal`: The service principal name of an AWS service for which the account
  is a delegated administrator. Delegated administrator privileges are revoked for only the
  specified AWS service from the member account. If the specified service is the only service
  for which the member account is a delegated administrator, the operation also revokes
  Organizations read action permissions.

"""
deregister_delegated_administrator(AccountId, ServicePrincipal; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("DeregisterDelegatedAdministrator", Dict{String, Any}("AccountId"=>AccountId, "ServicePrincipal"=>ServicePrincipal); aws_config=aws_config)
deregister_delegated_administrator(AccountId, ServicePrincipal, params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("DeregisterDelegatedAdministrator", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("AccountId"=>AccountId, "ServicePrincipal"=>ServicePrincipal), params)); aws_config=aws_config)

"""
    describe_account(account_id)
    describe_account(account_id, params::Dict{String,<:Any})

Retrieves AWS Organizations-related information about the specified account. This operation
can be called only from the organization's management account or by a member account that
is a delegated administrator for an AWS service.

# Arguments
- `account_id`: The unique identifier (ID) of the AWS account that you want information
  about. You can get the ID from the ListAccounts or ListAccountsForParent operations. The
  regex pattern for an account ID string requires exactly 12 digits.

"""
describe_account(AccountId; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("DescribeAccount", Dict{String, Any}("AccountId"=>AccountId); aws_config=aws_config)
describe_account(AccountId, params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("DescribeAccount", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("AccountId"=>AccountId), params)); aws_config=aws_config)

"""
    describe_create_account_status(create_account_request_id)
    describe_create_account_status(create_account_request_id, params::Dict{String,<:Any})

Retrieves the current status of an asynchronous request to create an account. This
operation can be called only from the organization's management account or by a member
account that is a delegated administrator for an AWS service.

# Arguments
- `create_account_request_id`: Specifies the Id value that uniquely identifies the
  CreateAccount request. You can get the value from the CreateAccountStatus.Id response in an
  earlier CreateAccount request, or from the ListCreateAccountStatus operation. The regex
  pattern for a create account request ID string requires \"car-\" followed by from 8 to 32
  lowercase letters or digits.

"""
describe_create_account_status(CreateAccountRequestId; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("DescribeCreateAccountStatus", Dict{String, Any}("CreateAccountRequestId"=>CreateAccountRequestId); aws_config=aws_config)
describe_create_account_status(CreateAccountRequestId, params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("DescribeCreateAccountStatus", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("CreateAccountRequestId"=>CreateAccountRequestId), params)); aws_config=aws_config)

"""
    describe_effective_policy(policy_type)
    describe_effective_policy(policy_type, params::Dict{String,<:Any})

Returns the contents of the effective policy for specified policy type and account. The
effective policy is the aggregation of any policies of the specified type that the account
inherits, plus any policy of that type that is directly attached to the account. This
operation applies only to policy types other than service control policies (SCPs). For more
information about policy inheritance, see How Policy Inheritance Works in the AWS
Organizations User Guide. This operation can be called only from the organization's
management account or by a member account that is a delegated administrator for an AWS
service.

# Arguments
- `policy_type`: The type of policy that you want information about. You can specify one of
  the following values:    AISERVICES_OPT_OUT_POLICY     BACKUP_POLICY     TAG_POLICY

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"TargetId"`: When you're signed in as the management account, specify the ID of the
  account that you want details about. Specifying an organization root or organizational unit
  (OU) as the target is not supported.
"""
describe_effective_policy(PolicyType; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("DescribeEffectivePolicy", Dict{String, Any}("PolicyType"=>PolicyType); aws_config=aws_config)
describe_effective_policy(PolicyType, params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("DescribeEffectivePolicy", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("PolicyType"=>PolicyType), params)); aws_config=aws_config)

"""
    describe_handshake(handshake_id)
    describe_handshake(handshake_id, params::Dict{String,<:Any})

Retrieves information about a previously requested handshake. The handshake ID comes from
the response to the original InviteAccountToOrganization operation that generated the
handshake. You can access handshakes that are ACCEPTED, DECLINED, or CANCELED for only 30
days after they change to that state. They're then deleted and no longer accessible. This
operation can be called from any account in the organization.

# Arguments
- `handshake_id`: The unique identifier (ID) of the handshake that you want information
  about. You can get the ID from the original call to InviteAccountToOrganization, or from a
  call to ListHandshakesForAccount or ListHandshakesForOrganization. The regex pattern for
  handshake ID string requires \"h-\" followed by from 8 to 32 lowercase letters or digits.

"""
describe_handshake(HandshakeId; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("DescribeHandshake", Dict{String, Any}("HandshakeId"=>HandshakeId); aws_config=aws_config)
describe_handshake(HandshakeId, params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("DescribeHandshake", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("HandshakeId"=>HandshakeId), params)); aws_config=aws_config)

"""
    describe_organization()
    describe_organization(params::Dict{String,<:Any})

Retrieves information about the organization that the user's account belongs to. This
operation can be called from any account in the organization.  Even if a policy type is
shown as available in the organization, you can disable it separately at the root level
with DisablePolicyType. Use ListRoots to see the status of policy types for a specified
root.

"""
describe_organization(; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("DescribeOrganization"; aws_config=aws_config)
describe_organization(params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("DescribeOrganization", params; aws_config=aws_config)

"""
    describe_organizational_unit(organizational_unit_id)
    describe_organizational_unit(organizational_unit_id, params::Dict{String,<:Any})

Retrieves information about an organizational unit (OU). This operation can be called only
from the organization's management account or by a member account that is a delegated
administrator for an AWS service.

# Arguments
- `organizational_unit_id`: The unique identifier (ID) of the organizational unit that you
  want details about. You can get the ID from the ListOrganizationalUnitsForParent operation.
  The regex pattern for an organizational unit ID string requires \"ou-\" followed by from 4
  to 32 lowercase letters or digits (the ID of the root that contains the OU). This string is
  followed by a second \"-\" dash and from 8 to 32 additional lowercase letters or digits.

"""
describe_organizational_unit(OrganizationalUnitId; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("DescribeOrganizationalUnit", Dict{String, Any}("OrganizationalUnitId"=>OrganizationalUnitId); aws_config=aws_config)
describe_organizational_unit(OrganizationalUnitId, params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("DescribeOrganizationalUnit", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("OrganizationalUnitId"=>OrganizationalUnitId), params)); aws_config=aws_config)

"""
    describe_policy(policy_id)
    describe_policy(policy_id, params::Dict{String,<:Any})

Retrieves information about a policy. This operation can be called only from the
organization's management account or by a member account that is a delegated administrator
for an AWS service.

# Arguments
- `policy_id`: The unique identifier (ID) of the policy that you want details about. You
  can get the ID from the ListPolicies or ListPoliciesForTarget operations. The regex pattern
  for a policy ID string requires \"p-\" followed by from 8 to 128 lowercase or uppercase
  letters, digits, or the underscore character (_).

"""
describe_policy(PolicyId; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("DescribePolicy", Dict{String, Any}("PolicyId"=>PolicyId); aws_config=aws_config)
describe_policy(PolicyId, params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("DescribePolicy", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("PolicyId"=>PolicyId), params)); aws_config=aws_config)

"""
    detach_policy(policy_id, target_id)
    detach_policy(policy_id, target_id, params::Dict{String,<:Any})

Detaches a policy from a target root, organizational unit (OU), or account.  If the policy
being detached is a service control policy (SCP), the changes to permissions for AWS
Identity and Access Management (IAM) users and roles in affected accounts are immediate.
Every root, OU, and account must have at least one SCP attached. If you want to replace the
default FullAWSAccess policy with an SCP that limits the permissions that can be delegated,
you must attach the replacement SCP before you can remove the default SCP. This is the
authorization strategy of an \"allow list\". If you instead attach a second SCP and leave
the FullAWSAccess SCP still attached, and specify \"Effect\": \"Deny\" in the second SCP to
override the \"Effect\": \"Allow\" in the FullAWSAccess policy (or any other attached SCP),
you're using the authorization strategy of a \"deny list\". This operation can be called
only from the organization's management account.

# Arguments
- `policy_id`: The unique identifier (ID) of the policy you want to detach. You can get the
  ID from the ListPolicies or ListPoliciesForTarget operations. The regex pattern for a
  policy ID string requires \"p-\" followed by from 8 to 128 lowercase or uppercase letters,
  digits, or the underscore character (_).
- `target_id`: The unique identifier (ID) of the root, OU, or account that you want to
  detach the policy from. You can get the ID from the ListRoots,
  ListOrganizationalUnitsForParent, or ListAccounts operations. The regex pattern for a
  target ID string requires one of the following:    Root - A string that begins with \"r-\"
  followed by from 4 to 32 lowercase letters or digits.    Account - A string that consists
  of exactly 12 digits.    Organizational unit (OU) - A string that begins with \"ou-\"
  followed by from 4 to 32 lowercase letters or digits (the ID of the root that the OU is
  in). This string is followed by a second \"-\" dash and from 8 to 32 additional lowercase
  letters or digits.

"""
detach_policy(PolicyId, TargetId; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("DetachPolicy", Dict{String, Any}("PolicyId"=>PolicyId, "TargetId"=>TargetId); aws_config=aws_config)
detach_policy(PolicyId, TargetId, params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("DetachPolicy", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("PolicyId"=>PolicyId, "TargetId"=>TargetId), params)); aws_config=aws_config)

"""
    disable_awsservice_access(service_principal)
    disable_awsservice_access(service_principal, params::Dict{String,<:Any})

Disables the integration of an AWS service (the service that is specified by
ServicePrincipal) with AWS Organizations. When you disable integration, the specified
service no longer can create a service-linked role in new accounts in your organization.
This means the service can't perform operations on your behalf on any new accounts in your
organization. The service can still perform operations in older accounts until the service
completes its clean-up from AWS Organizations.  We  strongly recommend  that you don't use
this command to disable integration between AWS Organizations and the specified AWS
service. Instead, use the console or commands that are provided by the specified service.
This lets the trusted service perform any required initialization when enabling trusted
access, such as creating any required resources and any required clean up of resources when
disabling trusted access.  For information about how to disable trusted service access to
your organization using the trusted service, see the Learn more link under the Supports
Trusted Access column at AWS services that you can use with AWS Organizations. on this
page. If you disable access by using this command, it causes the following actions to
occur:   The service can no longer create a service-linked role in the accounts in your
organization. This means that the service can't perform operations on your behalf on any
new accounts in your organization. The service can still perform operations in older
accounts until the service completes its clean-up from AWS Organizations.    The service
can no longer perform tasks in the member accounts in the organization, unless those
operations are explicitly permitted by the IAM policies that are attached to your roles.
This includes any data aggregation from the member accounts to the management account, or
to a delegated administrator account, where relevant.   Some services detect this and clean
up any remaining data or resources related to the integration, while other services stop
accessing the organization but leave any historical data and configuration in place to
support a possible re-enabling of the integration.   Using the other service's console or
commands to disable the integration ensures that the other service is aware that it can
clean up any resources that are required only for the integration. How the service cleans
up its resources in the organization's accounts depends on that service. For more
information, see the documentation for the other AWS service.   After you perform the
DisableAWSServiceAccess operation, the specified service can no longer perform operations
in your organization's accounts  For more information about integrating other services with
AWS Organizations, including the list of services that work with Organizations, see
Integrating AWS Organizations with Other AWS Services in the AWS Organizations User Guide.
This operation can be called only from the organization's management account.

# Arguments
- `service_principal`: The service principal name of the AWS service for which you want to
  disable integration with your organization. This is typically in the form of a URL, such as
   service-abbreviation.amazonaws.com.

"""
disable_awsservice_access(ServicePrincipal; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("DisableAWSServiceAccess", Dict{String, Any}("ServicePrincipal"=>ServicePrincipal); aws_config=aws_config)
disable_awsservice_access(ServicePrincipal, params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("DisableAWSServiceAccess", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("ServicePrincipal"=>ServicePrincipal), params)); aws_config=aws_config)

"""
    disable_policy_type(policy_type, root_id)
    disable_policy_type(policy_type, root_id, params::Dict{String,<:Any})

Disables an organizational policy type in a root. A policy of a certain type can be
attached to entities in a root only if that type is enabled in the root. After you perform
this operation, you no longer can attach policies of the specified type to that root or to
any organizational unit (OU) or account in that root. You can undo this by using the
EnablePolicyType operation. This is an asynchronous request that AWS performs in the
background. If you disable a policy type for a root, it still appears enabled for the
organization if all features are enabled for the organization. AWS recommends that you
first use ListRoots to see the status of policy types for a specified root, and then use
this operation. This operation can be called only from the organization's management
account.  To view the status of available policy types in the organization, use
DescribeOrganization.

# Arguments
- `policy_type`: The policy type that you want to disable in this root. You can specify one
  of the following values:    AISERVICES_OPT_OUT_POLICY     BACKUP_POLICY
  SERVICE_CONTROL_POLICY     TAG_POLICY
- `root_id`: The unique identifier (ID) of the root in which you want to disable a policy
  type. You can get the ID from the ListRoots operation. The regex pattern for a root ID
  string requires \"r-\" followed by from 4 to 32 lowercase letters or digits.

"""
disable_policy_type(PolicyType, RootId; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("DisablePolicyType", Dict{String, Any}("PolicyType"=>PolicyType, "RootId"=>RootId); aws_config=aws_config)
disable_policy_type(PolicyType, RootId, params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("DisablePolicyType", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("PolicyType"=>PolicyType, "RootId"=>RootId), params)); aws_config=aws_config)

"""
    enable_all_features()
    enable_all_features(params::Dict{String,<:Any})

Enables all features in an organization. This enables the use of organization policies that
can restrict the services and actions that can be called in each account. Until you enable
all features, you have access only to consolidated billing, and you can't use any of the
advanced account administration features that AWS Organizations supports. For more
information, see Enabling All Features in Your Organization in the AWS Organizations User
Guide.   This operation is required only for organizations that were created explicitly
with only the consolidated billing features enabled. Calling this operation sends a
handshake to every invited account in the organization. The feature set change can be
finalized and the additional features enabled only after all administrators in the invited
accounts approve the change by accepting the handshake.  After you enable all features, you
can separately enable or disable individual policy types in a root using EnablePolicyType
and DisablePolicyType. To see the status of policy types in a root, use ListRoots. After
all invited member accounts accept the handshake, you finalize the feature set change by
accepting the handshake that contains \"Action\": \"ENABLE_ALL_FEATURES\". This completes
the change. After you enable all features in your organization, the management account in
the organization can apply policies on all member accounts. These policies can restrict
what users and even administrators in those accounts can do. The management account can
apply policies that prevent accounts from leaving the organization. Ensure that your
account administrators are aware of this. This operation can be called only from the
organization's management account.

"""
enable_all_features(; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("EnableAllFeatures"; aws_config=aws_config)
enable_all_features(params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("EnableAllFeatures", params; aws_config=aws_config)

"""
    enable_awsservice_access(service_principal)
    enable_awsservice_access(service_principal, params::Dict{String,<:Any})

Enables the integration of an AWS service (the service that is specified by
ServicePrincipal) with AWS Organizations. When you enable integration, you allow the
specified service to create a service-linked role in all the accounts in your organization.
This allows the service to perform operations on your behalf in your organization and its
accounts.  We recommend that you enable integration between AWS Organizations and the
specified AWS service by using the console or commands that are provided by the specified
service. Doing so ensures that the service is aware that it can create the resources that
are required for the integration. How the service creates those resources in the
organization's accounts depends on that service. For more information, see the
documentation for the other AWS service.  For more information about enabling services to
integrate with AWS Organizations, see Integrating AWS Organizations with Other AWS Services
in the AWS Organizations User Guide.  This operation can be called only from the
organization's management account and only if the organization has enabled all features.

# Arguments
- `service_principal`: The service principal name of the AWS service for which you want to
  enable integration with your organization. This is typically in the form of a URL, such as
  service-abbreviation.amazonaws.com.

"""
enable_awsservice_access(ServicePrincipal; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("EnableAWSServiceAccess", Dict{String, Any}("ServicePrincipal"=>ServicePrincipal); aws_config=aws_config)
enable_awsservice_access(ServicePrincipal, params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("EnableAWSServiceAccess", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("ServicePrincipal"=>ServicePrincipal), params)); aws_config=aws_config)

"""
    enable_policy_type(policy_type, root_id)
    enable_policy_type(policy_type, root_id, params::Dict{String,<:Any})

Enables a policy type in a root. After you enable a policy type in a root, you can attach
policies of that type to the root, any organizational unit (OU), or account in that root.
You can undo this by using the DisablePolicyType operation. This is an asynchronous request
that AWS performs in the background. AWS recommends that you first use ListRoots to see the
status of policy types for a specified root, and then use this operation. This operation
can be called only from the organization's management account. You can enable a policy type
in a root only if that policy type is available in the organization. To view the status of
available policy types in the organization, use DescribeOrganization.

# Arguments
- `policy_type`: The policy type that you want to enable. You can specify one of the
  following values:    AISERVICES_OPT_OUT_POLICY     BACKUP_POLICY     SERVICE_CONTROL_POLICY
      TAG_POLICY
- `root_id`: The unique identifier (ID) of the root in which you want to enable a policy
  type. You can get the ID from the ListRoots operation. The regex pattern for a root ID
  string requires \"r-\" followed by from 4 to 32 lowercase letters or digits.

"""
enable_policy_type(PolicyType, RootId; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("EnablePolicyType", Dict{String, Any}("PolicyType"=>PolicyType, "RootId"=>RootId); aws_config=aws_config)
enable_policy_type(PolicyType, RootId, params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("EnablePolicyType", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("PolicyType"=>PolicyType, "RootId"=>RootId), params)); aws_config=aws_config)

"""
    invite_account_to_organization(target)
    invite_account_to_organization(target, params::Dict{String,<:Any})

Sends an invitation to another account to join your organization as a member account. AWS
Organizations sends email on your behalf to the email address that is associated with the
other account's owner. The invitation is implemented as a Handshake whose details are in
the response.    You can invite AWS accounts only from the same seller as the management
account. For example, if your organization's management account was created by Amazon
Internet Services Pvt. Ltd (AISPL), an AWS seller in India, you can invite only other AISPL
accounts to your organization. You can't combine accounts from AISPL and AWS or from any
other AWS seller. For more information, see Consolidated Billing in India.   If you receive
an exception that indicates that you exceeded your account limits for the organization or
that the operation failed because your organization is still initializing, wait one hour
and then try again. If the error persists after an hour, contact AWS Support.    If the
request includes tags, then the requester must have the organizations:TagResource
permission. This operation can be called only from the organization's management account.

# Arguments
- `target`: The identifier (ID) of the AWS account that you want to invite to join your
  organization. This is a JSON object that contains the following elements:  { \"Type\":
  \"ACCOUNT\", \"Id\": \"&lt; account id number &gt;\" }  If you use the AWS CLI, you can
  submit this as a single string, similar to the following example:  --target
  Id=123456789012,Type=ACCOUNT  If you specify \"Type\": \"ACCOUNT\", you must provide the
  AWS account ID number as the Id. If you specify \"Type\": \"EMAIL\", you must specify the
  email address that is associated with the account.  --target
  Id=diego@example.com,Type=EMAIL

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"Notes"`: Additional information that you want to include in the generated email to the
  recipient account owner.
- `"Tags"`: A list of tags that you want to attach to the account when it becomes a member
  of the organization. For each tag in the list, you must specify both a tag key and a value.
  You can set the value to an empty string, but you can't set it to null. For more
  information about tagging, see Tagging AWS Organizations resources in the AWS Organizations
  User Guide.  Any tags in the request are checked for compliance with any applicable tag
  policies when the request is made. The request is rejected if the tags in the request don't
  match the requirements of the policy at that time. Tag policy compliance is  not  checked
  again when the invitation is accepted and the tags are actually attached to the account.
  That means that if the tag policy changes between the invitation and the acceptance, then
  that tags could potentially be non-compliant.   If any one of the tags is invalid or if you
  exceed the allowed number of tags for an account, then the entire request fails and
  invitations are not sent.
"""
invite_account_to_organization(Target; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("InviteAccountToOrganization", Dict{String, Any}("Target"=>Target); aws_config=aws_config)
invite_account_to_organization(Target, params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("InviteAccountToOrganization", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("Target"=>Target), params)); aws_config=aws_config)

"""
    leave_organization()
    leave_organization(params::Dict{String,<:Any})

Removes a member account from its parent organization. This version of the operation is
performed by the account that wants to leave. To remove a member account as a user in the
management account, use RemoveAccountFromOrganization instead. This operation can be called
only from a member account in the organization.    The management account in an
organization with all features enabled can set service control policies (SCPs) that can
restrict what administrators of member accounts can do. This includes preventing them from
successfully calling LeaveOrganization and leaving the organization.   You can leave an
organization as a member account only if the account is configured with the information
required to operate as a standalone account. When you create an account in an organization
using the AWS Organizations console, API, or CLI commands, the information required of
standalone accounts is not automatically collected. For each account that you want to make
standalone, you must perform the following steps. If any of the steps are already completed
for this account, that step doesn't appear.   Choose a support plan   Provide and verify
the required contact information   Provide a current payment method   AWS uses the payment
method to charge for any billable (not free tier) AWS activity that occurs while the
account isn't attached to an organization. Follow the steps at  To leave an organization
when all required account information has not yet been provided in the AWS Organizations
User Guide.    The account that you want to leave must not be a delegated administrator
account for any AWS service enabled for your organization. If the account is a delegated
administrator, you must first change the delegated administrator account to another account
that is remaining in the organization.   You can leave an organization only after you
enable IAM user access to billing in your account. For more information, see Activating
Access to the Billing and Cost Management Console in the AWS Billing and Cost Management
User Guide.    After the account leaves the organization, all tags that were attached to
the account object in the organization are deleted. AWS accounts outside of an organization
do not support tags.   A newly created account has a waiting period before it can be
removed from its organization. If you get an error that indicates that a wait period is
required, then try again in a few days.

"""
leave_organization(; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("LeaveOrganization"; aws_config=aws_config)
leave_organization(params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("LeaveOrganization", params; aws_config=aws_config)

"""
    list_accounts()
    list_accounts(params::Dict{String,<:Any})

Lists all the accounts in the organization. To request only the accounts in a specified
root or organizational unit (OU), use the ListAccountsForParent operation instead.  Always
check the NextToken response parameter for a null value when calling a List* operation.
These operations can occasionally return an empty set of results even when there are more
results available. The NextToken response parameter value is null only when there are no
more results to display.  This operation can be called only from the organization's
management account or by a member account that is a delegated administrator for an AWS
service.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"MaxResults"`: The total number of results that you want included on each page of the
  response. If you do not include this parameter, it defaults to a value that is specific to
  the operation. If additional items exist beyond the maximum you specify, the NextToken
  response element is present and has a value (is not null). Include that value as the
  NextToken request parameter in the next call to the operation to get the next part of the
  results. Note that Organizations might return fewer results than the maximum even when
  there are more results available. You should check NextToken after every operation to
  ensure that you receive all of the results.
- `"NextToken"`: The parameter for receiving additional results if you receive a NextToken
  response in a previous request. A NextToken response indicates that more output is
  available. Set this parameter to the value of the previous call's NextToken response to
  indicate where the output should continue from.
"""
list_accounts(; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("ListAccounts"; aws_config=aws_config)
list_accounts(params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("ListAccounts", params; aws_config=aws_config)

"""
    list_accounts_for_parent(parent_id)
    list_accounts_for_parent(parent_id, params::Dict{String,<:Any})

Lists the accounts in an organization that are contained by the specified target root or
organizational unit (OU). If you specify the root, you get a list of all the accounts that
aren't in any OU. If you specify an OU, you get a list of all the accounts in only that OU
and not in any child OUs. To get a list of all accounts in the organization, use the
ListAccounts operation.  Always check the NextToken response parameter for a null value
when calling a List* operation. These operations can occasionally return an empty set of
results even when there are more results available. The NextToken response parameter value
is null only when there are no more results to display.  This operation can be called only
from the organization's management account or by a member account that is a delegated
administrator for an AWS service.

# Arguments
- `parent_id`: The unique identifier (ID) for the parent root or organization unit (OU)
  whose accounts you want to list.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"MaxResults"`: The total number of results that you want included on each page of the
  response. If you do not include this parameter, it defaults to a value that is specific to
  the operation. If additional items exist beyond the maximum you specify, the NextToken
  response element is present and has a value (is not null). Include that value as the
  NextToken request parameter in the next call to the operation to get the next part of the
  results. Note that Organizations might return fewer results than the maximum even when
  there are more results available. You should check NextToken after every operation to
  ensure that you receive all of the results.
- `"NextToken"`: The parameter for receiving additional results if you receive a NextToken
  response in a previous request. A NextToken response indicates that more output is
  available. Set this parameter to the value of the previous call's NextToken response to
  indicate where the output should continue from.
"""
list_accounts_for_parent(ParentId; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("ListAccountsForParent", Dict{String, Any}("ParentId"=>ParentId); aws_config=aws_config)
list_accounts_for_parent(ParentId, params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("ListAccountsForParent", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("ParentId"=>ParentId), params)); aws_config=aws_config)

"""
    list_awsservice_access_for_organization()
    list_awsservice_access_for_organization(params::Dict{String,<:Any})

Returns a list of the AWS services that you enabled to integrate with your organization.
After a service on this list creates the resources that it requires for the integration, it
can perform operations on your organization and its accounts. For more information about
integrating other services with AWS Organizations, including the list of services that
currently work with Organizations, see Integrating AWS Organizations with Other AWS
Services in the AWS Organizations User Guide.  This operation can be called only from the
organization's management account or by a member account that is a delegated administrator
for an AWS service.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"MaxResults"`: The total number of results that you want included on each page of the
  response. If you do not include this parameter, it defaults to a value that is specific to
  the operation. If additional items exist beyond the maximum you specify, the NextToken
  response element is present and has a value (is not null). Include that value as the
  NextToken request parameter in the next call to the operation to get the next part of the
  results. Note that Organizations might return fewer results than the maximum even when
  there are more results available. You should check NextToken after every operation to
  ensure that you receive all of the results.
- `"NextToken"`: The parameter for receiving additional results if you receive a NextToken
  response in a previous request. A NextToken response indicates that more output is
  available. Set this parameter to the value of the previous call's NextToken response to
  indicate where the output should continue from.
"""
list_awsservice_access_for_organization(; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("ListAWSServiceAccessForOrganization"; aws_config=aws_config)
list_awsservice_access_for_organization(params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("ListAWSServiceAccessForOrganization", params; aws_config=aws_config)

"""
    list_children(child_type, parent_id)
    list_children(child_type, parent_id, params::Dict{String,<:Any})

Lists all of the organizational units (OUs) or accounts that are contained in the specified
parent OU or root. This operation, along with ListParents enables you to traverse the tree
structure that makes up this root.  Always check the NextToken response parameter for a
null value when calling a List* operation. These operations can occasionally return an
empty set of results even when there are more results available. The NextToken response
parameter value is null only when there are no more results to display.  This operation can
be called only from the organization's management account or by a member account that is a
delegated administrator for an AWS service.

# Arguments
- `child_type`: Filters the output to include only the specified child type.
- `parent_id`: The unique identifier (ID) for the parent root or OU whose children you want
  to list. The regex pattern for a parent ID string requires one of the following:    Root -
  A string that begins with \"r-\" followed by from 4 to 32 lowercase letters or digits.
  Organizational unit (OU) - A string that begins with \"ou-\" followed by from 4 to 32
  lowercase letters or digits (the ID of the root that the OU is in). This string is followed
  by a second \"-\" dash and from 8 to 32 additional lowercase letters or digits.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"MaxResults"`: The total number of results that you want included on each page of the
  response. If you do not include this parameter, it defaults to a value that is specific to
  the operation. If additional items exist beyond the maximum you specify, the NextToken
  response element is present and has a value (is not null). Include that value as the
  NextToken request parameter in the next call to the operation to get the next part of the
  results. Note that Organizations might return fewer results than the maximum even when
  there are more results available. You should check NextToken after every operation to
  ensure that you receive all of the results.
- `"NextToken"`: The parameter for receiving additional results if you receive a NextToken
  response in a previous request. A NextToken response indicates that more output is
  available. Set this parameter to the value of the previous call's NextToken response to
  indicate where the output should continue from.
"""
list_children(ChildType, ParentId; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("ListChildren", Dict{String, Any}("ChildType"=>ChildType, "ParentId"=>ParentId); aws_config=aws_config)
list_children(ChildType, ParentId, params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("ListChildren", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("ChildType"=>ChildType, "ParentId"=>ParentId), params)); aws_config=aws_config)

"""
    list_create_account_status()
    list_create_account_status(params::Dict{String,<:Any})

Lists the account creation requests that match the specified status that is currently being
tracked for the organization.  Always check the NextToken response parameter for a null
value when calling a List* operation. These operations can occasionally return an empty set
of results even when there are more results available. The NextToken response parameter
value is null only when there are no more results to display.  This operation can be called
only from the organization's management account or by a member account that is a delegated
administrator for an AWS service.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"MaxResults"`: The total number of results that you want included on each page of the
  response. If you do not include this parameter, it defaults to a value that is specific to
  the operation. If additional items exist beyond the maximum you specify, the NextToken
  response element is present and has a value (is not null). Include that value as the
  NextToken request parameter in the next call to the operation to get the next part of the
  results. Note that Organizations might return fewer results than the maximum even when
  there are more results available. You should check NextToken after every operation to
  ensure that you receive all of the results.
- `"NextToken"`: The parameter for receiving additional results if you receive a NextToken
  response in a previous request. A NextToken response indicates that more output is
  available. Set this parameter to the value of the previous call's NextToken response to
  indicate where the output should continue from.
- `"States"`: A list of one or more states that you want included in the response. If this
  parameter isn't present, all requests are included in the response.
"""
list_create_account_status(; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("ListCreateAccountStatus"; aws_config=aws_config)
list_create_account_status(params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("ListCreateAccountStatus", params; aws_config=aws_config)

"""
    list_delegated_administrators()
    list_delegated_administrators(params::Dict{String,<:Any})

Lists the AWS accounts that are designated as delegated administrators in this
organization. This operation can be called only from the organization's management account
or by a member account that is a delegated administrator for an AWS service.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"MaxResults"`: The total number of results that you want included on each page of the
  response. If you do not include this parameter, it defaults to a value that is specific to
  the operation. If additional items exist beyond the maximum you specify, the NextToken
  response element is present and has a value (is not null). Include that value as the
  NextToken request parameter in the next call to the operation to get the next part of the
  results. Note that Organizations might return fewer results than the maximum even when
  there are more results available. You should check NextToken after every operation to
  ensure that you receive all of the results.
- `"NextToken"`: The parameter for receiving additional results if you receive a NextToken
  response in a previous request. A NextToken response indicates that more output is
  available. Set this parameter to the value of the previous call's NextToken response to
  indicate where the output should continue from.
- `"ServicePrincipal"`: Specifies a service principal name. If specified, then the
  operation lists the delegated administrators only for the specified service. If you don't
  specify a service principal, the operation lists all delegated administrators for all
  services in your organization.
"""
list_delegated_administrators(; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("ListDelegatedAdministrators"; aws_config=aws_config)
list_delegated_administrators(params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("ListDelegatedAdministrators", params; aws_config=aws_config)

"""
    list_delegated_services_for_account(account_id)
    list_delegated_services_for_account(account_id, params::Dict{String,<:Any})

List the AWS services for which the specified account is a delegated administrator. This
operation can be called only from the organization's management account or by a member
account that is a delegated administrator for an AWS service.

# Arguments
- `account_id`: The account ID number of a delegated administrator account in the
  organization.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"MaxResults"`: The total number of results that you want included on each page of the
  response. If you do not include this parameter, it defaults to a value that is specific to
  the operation. If additional items exist beyond the maximum you specify, the NextToken
  response element is present and has a value (is not null). Include that value as the
  NextToken request parameter in the next call to the operation to get the next part of the
  results. Note that Organizations might return fewer results than the maximum even when
  there are more results available. You should check NextToken after every operation to
  ensure that you receive all of the results.
- `"NextToken"`: The parameter for receiving additional results if you receive a NextToken
  response in a previous request. A NextToken response indicates that more output is
  available. Set this parameter to the value of the previous call's NextToken response to
  indicate where the output should continue from.
"""
list_delegated_services_for_account(AccountId; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("ListDelegatedServicesForAccount", Dict{String, Any}("AccountId"=>AccountId); aws_config=aws_config)
list_delegated_services_for_account(AccountId, params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("ListDelegatedServicesForAccount", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("AccountId"=>AccountId), params)); aws_config=aws_config)

"""
    list_handshakes_for_account()
    list_handshakes_for_account(params::Dict{String,<:Any})

Lists the current handshakes that are associated with the account of the requesting user.
Handshakes that are ACCEPTED, DECLINED, or CANCELED appear in the results of this API for
only 30 days after changing to that state. After that, they're deleted and no longer
accessible.  Always check the NextToken response parameter for a null value when calling a
List* operation. These operations can occasionally return an empty set of results even when
there are more results available. The NextToken response parameter value is null only when
there are no more results to display.  This operation can be called from any account in the
organization.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"Filter"`: Filters the handshakes that you want included in the response. The default is
  all types. Use the ActionType element to limit the output to only a specified type, such as
  INVITE, ENABLE_ALL_FEATURES, or APPROVE_ALL_FEATURES. Alternatively, for the
  ENABLE_ALL_FEATURES handshake that generates a separate child handshake for each member
  account, you can specify ParentHandshakeId to see only the handshakes that were generated
  by that parent request.
- `"MaxResults"`: The total number of results that you want included on each page of the
  response. If you do not include this parameter, it defaults to a value that is specific to
  the operation. If additional items exist beyond the maximum you specify, the NextToken
  response element is present and has a value (is not null). Include that value as the
  NextToken request parameter in the next call to the operation to get the next part of the
  results. Note that Organizations might return fewer results than the maximum even when
  there are more results available. You should check NextToken after every operation to
  ensure that you receive all of the results.
- `"NextToken"`: The parameter for receiving additional results if you receive a NextToken
  response in a previous request. A NextToken response indicates that more output is
  available. Set this parameter to the value of the previous call's NextToken response to
  indicate where the output should continue from.
"""
list_handshakes_for_account(; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("ListHandshakesForAccount"; aws_config=aws_config)
list_handshakes_for_account(params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("ListHandshakesForAccount", params; aws_config=aws_config)

"""
    list_handshakes_for_organization()
    list_handshakes_for_organization(params::Dict{String,<:Any})

Lists the handshakes that are associated with the organization that the requesting user is
part of. The ListHandshakesForOrganization operation returns a list of handshake
structures. Each structure contains details and status about a handshake. Handshakes that
are ACCEPTED, DECLINED, or CANCELED appear in the results of this API for only 30 days
after changing to that state. After that, they're deleted and no longer accessible.  Always
check the NextToken response parameter for a null value when calling a List* operation.
These operations can occasionally return an empty set of results even when there are more
results available. The NextToken response parameter value is null only when there are no
more results to display.  This operation can be called only from the organization's
management account or by a member account that is a delegated administrator for an AWS
service.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"Filter"`: A filter of the handshakes that you want included in the response. The
  default is all types. Use the ActionType element to limit the output to only a specified
  type, such as INVITE, ENABLE-ALL-FEATURES, or APPROVE-ALL-FEATURES. Alternatively, for the
  ENABLE-ALL-FEATURES handshake that generates a separate child handshake for each member
  account, you can specify the ParentHandshakeId to see only the handshakes that were
  generated by that parent request.
- `"MaxResults"`: The total number of results that you want included on each page of the
  response. If you do not include this parameter, it defaults to a value that is specific to
  the operation. If additional items exist beyond the maximum you specify, the NextToken
  response element is present and has a value (is not null). Include that value as the
  NextToken request parameter in the next call to the operation to get the next part of the
  results. Note that Organizations might return fewer results than the maximum even when
  there are more results available. You should check NextToken after every operation to
  ensure that you receive all of the results.
- `"NextToken"`: The parameter for receiving additional results if you receive a NextToken
  response in a previous request. A NextToken response indicates that more output is
  available. Set this parameter to the value of the previous call's NextToken response to
  indicate where the output should continue from.
"""
list_handshakes_for_organization(; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("ListHandshakesForOrganization"; aws_config=aws_config)
list_handshakes_for_organization(params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("ListHandshakesForOrganization", params; aws_config=aws_config)

"""
    list_organizational_units_for_parent(parent_id)
    list_organizational_units_for_parent(parent_id, params::Dict{String,<:Any})

Lists the organizational units (OUs) in a parent organizational unit or root.  Always check
the NextToken response parameter for a null value when calling a List* operation. These
operations can occasionally return an empty set of results even when there are more results
available. The NextToken response parameter value is null only when there are no more
results to display.  This operation can be called only from the organization's management
account or by a member account that is a delegated administrator for an AWS service.

# Arguments
- `parent_id`: The unique identifier (ID) of the root or OU whose child OUs you want to
  list. The regex pattern for a parent ID string requires one of the following:    Root - A
  string that begins with \"r-\" followed by from 4 to 32 lowercase letters or digits.
  Organizational unit (OU) - A string that begins with \"ou-\" followed by from 4 to 32
  lowercase letters or digits (the ID of the root that the OU is in). This string is followed
  by a second \"-\" dash and from 8 to 32 additional lowercase letters or digits.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"MaxResults"`: The total number of results that you want included on each page of the
  response. If you do not include this parameter, it defaults to a value that is specific to
  the operation. If additional items exist beyond the maximum you specify, the NextToken
  response element is present and has a value (is not null). Include that value as the
  NextToken request parameter in the next call to the operation to get the next part of the
  results. Note that Organizations might return fewer results than the maximum even when
  there are more results available. You should check NextToken after every operation to
  ensure that you receive all of the results.
- `"NextToken"`: The parameter for receiving additional results if you receive a NextToken
  response in a previous request. A NextToken response indicates that more output is
  available. Set this parameter to the value of the previous call's NextToken response to
  indicate where the output should continue from.
"""
list_organizational_units_for_parent(ParentId; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("ListOrganizationalUnitsForParent", Dict{String, Any}("ParentId"=>ParentId); aws_config=aws_config)
list_organizational_units_for_parent(ParentId, params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("ListOrganizationalUnitsForParent", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("ParentId"=>ParentId), params)); aws_config=aws_config)

"""
    list_parents(child_id)
    list_parents(child_id, params::Dict{String,<:Any})

Lists the root or organizational units (OUs) that serve as the immediate parent of the
specified child OU or account. This operation, along with ListChildren enables you to
traverse the tree structure that makes up this root.  Always check the NextToken response
parameter for a null value when calling a List* operation. These operations can
occasionally return an empty set of results even when there are more results available. The
NextToken response parameter value is null only when there are no more results to display.
This operation can be called only from the organization's management account or by a member
account that is a delegated administrator for an AWS service.  In the current release, a
child can have only a single parent.

# Arguments
- `child_id`: The unique identifier (ID) of the OU or account whose parent containers you
  want to list. Don't specify a root. The regex pattern for a child ID string requires one of
  the following:    Account - A string that consists of exactly 12 digits.    Organizational
  unit (OU) - A string that begins with \"ou-\" followed by from 4 to 32 lowercase letters or
  digits (the ID of the root that contains the OU). This string is followed by a second \"-\"
  dash and from 8 to 32 additional lowercase letters or digits.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"MaxResults"`: The total number of results that you want included on each page of the
  response. If you do not include this parameter, it defaults to a value that is specific to
  the operation. If additional items exist beyond the maximum you specify, the NextToken
  response element is present and has a value (is not null). Include that value as the
  NextToken request parameter in the next call to the operation to get the next part of the
  results. Note that Organizations might return fewer results than the maximum even when
  there are more results available. You should check NextToken after every operation to
  ensure that you receive all of the results.
- `"NextToken"`: The parameter for receiving additional results if you receive a NextToken
  response in a previous request. A NextToken response indicates that more output is
  available. Set this parameter to the value of the previous call's NextToken response to
  indicate where the output should continue from.
"""
list_parents(ChildId; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("ListParents", Dict{String, Any}("ChildId"=>ChildId); aws_config=aws_config)
list_parents(ChildId, params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("ListParents", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("ChildId"=>ChildId), params)); aws_config=aws_config)

"""
    list_policies(filter)
    list_policies(filter, params::Dict{String,<:Any})

Retrieves the list of all policies in an organization of a specified type.  Always check
the NextToken response parameter for a null value when calling a List* operation. These
operations can occasionally return an empty set of results even when there are more results
available. The NextToken response parameter value is null only when there are no more
results to display.  This operation can be called only from the organization's management
account or by a member account that is a delegated administrator for an AWS service.

# Arguments
- `filter`: Specifies the type of policy that you want to include in the response. You must
  specify one of the following values:    AISERVICES_OPT_OUT_POLICY     BACKUP_POLICY
  SERVICE_CONTROL_POLICY     TAG_POLICY

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"MaxResults"`: The total number of results that you want included on each page of the
  response. If you do not include this parameter, it defaults to a value that is specific to
  the operation. If additional items exist beyond the maximum you specify, the NextToken
  response element is present and has a value (is not null). Include that value as the
  NextToken request parameter in the next call to the operation to get the next part of the
  results. Note that Organizations might return fewer results than the maximum even when
  there are more results available. You should check NextToken after every operation to
  ensure that you receive all of the results.
- `"NextToken"`: The parameter for receiving additional results if you receive a NextToken
  response in a previous request. A NextToken response indicates that more output is
  available. Set this parameter to the value of the previous call's NextToken response to
  indicate where the output should continue from.
"""
list_policies(Filter; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("ListPolicies", Dict{String, Any}("Filter"=>Filter); aws_config=aws_config)
list_policies(Filter, params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("ListPolicies", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("Filter"=>Filter), params)); aws_config=aws_config)

"""
    list_policies_for_target(filter, target_id)
    list_policies_for_target(filter, target_id, params::Dict{String,<:Any})

Lists the policies that are directly attached to the specified target root, organizational
unit (OU), or account. You must specify the policy type that you want included in the
returned list.  Always check the NextToken response parameter for a null value when calling
a List* operation. These operations can occasionally return an empty set of results even
when there are more results available. The NextToken response parameter value is null only
when there are no more results to display.  This operation can be called only from the
organization's management account or by a member account that is a delegated administrator
for an AWS service.

# Arguments
- `filter`: The type of policy that you want to include in the returned list. You must
  specify one of the following values:    AISERVICES_OPT_OUT_POLICY     BACKUP_POLICY
  SERVICE_CONTROL_POLICY     TAG_POLICY
- `target_id`: The unique identifier (ID) of the root, organizational unit, or account
  whose policies you want to list. The regex pattern for a target ID string requires one of
  the following:    Root - A string that begins with \"r-\" followed by from 4 to 32
  lowercase letters or digits.    Account - A string that consists of exactly 12 digits.
  Organizational unit (OU) - A string that begins with \"ou-\" followed by from 4 to 32
  lowercase letters or digits (the ID of the root that the OU is in). This string is followed
  by a second \"-\" dash and from 8 to 32 additional lowercase letters or digits.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"MaxResults"`: The total number of results that you want included on each page of the
  response. If you do not include this parameter, it defaults to a value that is specific to
  the operation. If additional items exist beyond the maximum you specify, the NextToken
  response element is present and has a value (is not null). Include that value as the
  NextToken request parameter in the next call to the operation to get the next part of the
  results. Note that Organizations might return fewer results than the maximum even when
  there are more results available. You should check NextToken after every operation to
  ensure that you receive all of the results.
- `"NextToken"`: The parameter for receiving additional results if you receive a NextToken
  response in a previous request. A NextToken response indicates that more output is
  available. Set this parameter to the value of the previous call's NextToken response to
  indicate where the output should continue from.
"""
list_policies_for_target(Filter, TargetId; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("ListPoliciesForTarget", Dict{String, Any}("Filter"=>Filter, "TargetId"=>TargetId); aws_config=aws_config)
list_policies_for_target(Filter, TargetId, params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("ListPoliciesForTarget", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("Filter"=>Filter, "TargetId"=>TargetId), params)); aws_config=aws_config)

"""
    list_roots()
    list_roots(params::Dict{String,<:Any})

Lists the roots that are defined in the current organization.  Always check the NextToken
response parameter for a null value when calling a List* operation. These operations can
occasionally return an empty set of results even when there are more results available. The
NextToken response parameter value is null only when there are no more results to display.
This operation can be called only from the organization's management account or by a member
account that is a delegated administrator for an AWS service.  Policy types can be enabled
and disabled in roots. This is distinct from whether they're available in the organization.
When you enable all features, you make policy types available for use in that organization.
Individual policy types can then be enabled and disabled in a root. To see the availability
of a policy type in an organization, use DescribeOrganization.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"MaxResults"`: The total number of results that you want included on each page of the
  response. If you do not include this parameter, it defaults to a value that is specific to
  the operation. If additional items exist beyond the maximum you specify, the NextToken
  response element is present and has a value (is not null). Include that value as the
  NextToken request parameter in the next call to the operation to get the next part of the
  results. Note that Organizations might return fewer results than the maximum even when
  there are more results available. You should check NextToken after every operation to
  ensure that you receive all of the results.
- `"NextToken"`: The parameter for receiving additional results if you receive a NextToken
  response in a previous request. A NextToken response indicates that more output is
  available. Set this parameter to the value of the previous call's NextToken response to
  indicate where the output should continue from.
"""
list_roots(; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("ListRoots"; aws_config=aws_config)
list_roots(params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("ListRoots", params; aws_config=aws_config)

"""
    list_tags_for_resource(resource_id)
    list_tags_for_resource(resource_id, params::Dict{String,<:Any})

Lists tags that are attached to the specified resource. You can attach tags to the
following resources in AWS Organizations.   AWS account   Organization root
Organizational unit (OU)   Policy (any type)   This operation can be called only from the
organization's management account or by a member account that is a delegated administrator
for an AWS service.

# Arguments
- `resource_id`: The ID of the resource with the tags to list. You can specify any of the
  following taggable resources.   AWS account – specify the account ID number.
  Organizational unit – specify the OU ID that begins with ou- and looks similar to:
  ou-1a2b-34uvwxyz     Root – specify the root ID that begins with r- and looks similar to:
  r-1a2b     Policy – specify the policy ID that begins with p- andlooks similar to:
  p-12abcdefg3

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"NextToken"`: The parameter for receiving additional results if you receive a NextToken
  response in a previous request. A NextToken response indicates that more output is
  available. Set this parameter to the value of the previous call's NextToken response to
  indicate where the output should continue from.
"""
list_tags_for_resource(ResourceId; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("ListTagsForResource", Dict{String, Any}("ResourceId"=>ResourceId); aws_config=aws_config)
list_tags_for_resource(ResourceId, params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("ListTagsForResource", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("ResourceId"=>ResourceId), params)); aws_config=aws_config)

"""
    list_targets_for_policy(policy_id)
    list_targets_for_policy(policy_id, params::Dict{String,<:Any})

Lists all the roots, organizational units (OUs), and accounts that the specified policy is
attached to.  Always check the NextToken response parameter for a null value when calling a
List* operation. These operations can occasionally return an empty set of results even when
there are more results available. The NextToken response parameter value is null only when
there are no more results to display.  This operation can be called only from the
organization's management account or by a member account that is a delegated administrator
for an AWS service.

# Arguments
- `policy_id`: The unique identifier (ID) of the policy whose attachments you want to know.
  The regex pattern for a policy ID string requires \"p-\" followed by from 8 to 128
  lowercase or uppercase letters, digits, or the underscore character (_).

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"MaxResults"`: The total number of results that you want included on each page of the
  response. If you do not include this parameter, it defaults to a value that is specific to
  the operation. If additional items exist beyond the maximum you specify, the NextToken
  response element is present and has a value (is not null). Include that value as the
  NextToken request parameter in the next call to the operation to get the next part of the
  results. Note that Organizations might return fewer results than the maximum even when
  there are more results available. You should check NextToken after every operation to
  ensure that you receive all of the results.
- `"NextToken"`: The parameter for receiving additional results if you receive a NextToken
  response in a previous request. A NextToken response indicates that more output is
  available. Set this parameter to the value of the previous call's NextToken response to
  indicate where the output should continue from.
"""
list_targets_for_policy(PolicyId; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("ListTargetsForPolicy", Dict{String, Any}("PolicyId"=>PolicyId); aws_config=aws_config)
list_targets_for_policy(PolicyId, params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("ListTargetsForPolicy", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("PolicyId"=>PolicyId), params)); aws_config=aws_config)

"""
    move_account(account_id, destination_parent_id, source_parent_id)
    move_account(account_id, destination_parent_id, source_parent_id, params::Dict{String,<:Any})

Moves an account from its current source parent root or organizational unit (OU) to the
specified destination parent root or OU. This operation can be called only from the
organization's management account.

# Arguments
- `account_id`: The unique identifier (ID) of the account that you want to move. The regex
  pattern for an account ID string requires exactly 12 digits.
- `destination_parent_id`: The unique identifier (ID) of the root or organizational unit
  that you want to move the account to. The regex pattern for a parent ID string requires one
  of the following:    Root - A string that begins with \"r-\" followed by from 4 to 32
  lowercase letters or digits.    Organizational unit (OU) - A string that begins with
  \"ou-\" followed by from 4 to 32 lowercase letters or digits (the ID of the root that the
  OU is in). This string is followed by a second \"-\" dash and from 8 to 32 additional
  lowercase letters or digits.
- `source_parent_id`: The unique identifier (ID) of the root or organizational unit that
  you want to move the account from. The regex pattern for a parent ID string requires one of
  the following:    Root - A string that begins with \"r-\" followed by from 4 to 32
  lowercase letters or digits.    Organizational unit (OU) - A string that begins with
  \"ou-\" followed by from 4 to 32 lowercase letters or digits (the ID of the root that the
  OU is in). This string is followed by a second \"-\" dash and from 8 to 32 additional
  lowercase letters or digits.

"""
move_account(AccountId, DestinationParentId, SourceParentId; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("MoveAccount", Dict{String, Any}("AccountId"=>AccountId, "DestinationParentId"=>DestinationParentId, "SourceParentId"=>SourceParentId); aws_config=aws_config)
move_account(AccountId, DestinationParentId, SourceParentId, params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("MoveAccount", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("AccountId"=>AccountId, "DestinationParentId"=>DestinationParentId, "SourceParentId"=>SourceParentId), params)); aws_config=aws_config)

"""
    register_delegated_administrator(account_id, service_principal)
    register_delegated_administrator(account_id, service_principal, params::Dict{String,<:Any})

Enables the specified member account to administer the Organizations features of the
specified AWS service. It grants read-only access to AWS Organizations service data. The
account still requires IAM permissions to access and administer the AWS service. You can
run this action only for AWS services that support this feature. For a current list of
services that support it, see the column Supports Delegated Administrator in the table at
AWS Services that you can use with AWS Organizations in the AWS Organizations User Guide.
This operation can be called only from the organization's management account.

# Arguments
- `account_id`: The account ID number of the member account in the organization to register
  as a delegated administrator.
- `service_principal`: The service principal of the AWS service for which you want to make
  the member account a delegated administrator.

"""
register_delegated_administrator(AccountId, ServicePrincipal; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("RegisterDelegatedAdministrator", Dict{String, Any}("AccountId"=>AccountId, "ServicePrincipal"=>ServicePrincipal); aws_config=aws_config)
register_delegated_administrator(AccountId, ServicePrincipal, params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("RegisterDelegatedAdministrator", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("AccountId"=>AccountId, "ServicePrincipal"=>ServicePrincipal), params)); aws_config=aws_config)

"""
    remove_account_from_organization(account_id)
    remove_account_from_organization(account_id, params::Dict{String,<:Any})

Removes the specified account from the organization. The removed account becomes a
standalone account that isn't a member of any organization. It's no longer subject to any
policies and is responsible for its own bill payments. The organization's management
account is no longer charged for any expenses accrued by the member account after it's
removed from the organization. This operation can be called only from the organization's
management account. Member accounts can remove themselves with LeaveOrganization instead.
 You can remove an account from your organization only if the account is configured with
the information required to operate as a standalone account. When you create an account in
an organization using the AWS Organizations console, API, or CLI commands, the information
required of standalone accounts is not automatically collected. For an account that you
want to make standalone, you must choose a support plan, provide and verify the required
contact information, and provide a current payment method. AWS uses the payment method to
charge for any billable (not free tier) AWS activity that occurs while the account isn't
attached to an organization. To remove an account that doesn't yet have this information,
you must sign in as the member account and follow the steps at  To leave an organization
when all required account information has not yet been provided in the AWS Organizations
User Guide.    The account that you want to leave must not be a delegated administrator
account for any AWS service enabled for your organization. If the account is a delegated
administrator, you must first change the delegated administrator account to another account
that is remaining in the organization.   After the account leaves the organization, all
tags that were attached to the account object in the organization are deleted. AWS accounts
outside of an organization do not support tags.

# Arguments
- `account_id`: The unique identifier (ID) of the member account that you want to remove
  from the organization. The regex pattern for an account ID string requires exactly 12
  digits.

"""
remove_account_from_organization(AccountId; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("RemoveAccountFromOrganization", Dict{String, Any}("AccountId"=>AccountId); aws_config=aws_config)
remove_account_from_organization(AccountId, params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("RemoveAccountFromOrganization", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("AccountId"=>AccountId), params)); aws_config=aws_config)

"""
    tag_resource(resource_id, tags)
    tag_resource(resource_id, tags, params::Dict{String,<:Any})

Adds one or more tags to the specified resource. Currently, you can attach tags to the
following resources in AWS Organizations.   AWS account   Organization root
Organizational unit (OU)   Policy (any type)   This operation can be called only from the
organization's management account.

# Arguments
- `resource_id`: The ID of the resource to add a tag to.
- `tags`: A list of tags to add to the specified resource. You can specify any of the
  following taggable resources.   AWS account – specify the account ID number.
  Organizational unit – specify the OU ID that begins with ou- and looks similar to:
  ou-1a2b-34uvwxyz     Root – specify the root ID that begins with r- and looks similar to:
  r-1a2b     Policy – specify the policy ID that begins with p- andlooks similar to:
  p-12abcdefg3     For each tag in the list, you must specify both a tag key and a value. You
  can set the value to an empty string, but you can't set it to null.  If any one of the tags
  is invalid or if you exceed the allowed number of tags for an account user, then the entire
  request fails and the account is not created.

"""
tag_resource(ResourceId, Tags; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("TagResource", Dict{String, Any}("ResourceId"=>ResourceId, "Tags"=>Tags); aws_config=aws_config)
tag_resource(ResourceId, Tags, params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("TagResource", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("ResourceId"=>ResourceId, "Tags"=>Tags), params)); aws_config=aws_config)

"""
    untag_resource(resource_id, tag_keys)
    untag_resource(resource_id, tag_keys, params::Dict{String,<:Any})

Removes any tags with the specified keys from the specified resource. You can attach tags
to the following resources in AWS Organizations.   AWS account   Organization root
Organizational unit (OU)   Policy (any type)   This operation can be called only from the
organization's management account.

# Arguments
- `resource_id`: The ID of the resource to remove a tag from. You can specify any of the
  following taggable resources.   AWS account – specify the account ID number.
  Organizational unit – specify the OU ID that begins with ou- and looks similar to:
  ou-1a2b-34uvwxyz     Root – specify the root ID that begins with r- and looks similar to:
  r-1a2b     Policy – specify the policy ID that begins with p- andlooks similar to:
  p-12abcdefg3
- `tag_keys`: The list of keys for tags to remove from the specified resource.

"""
untag_resource(ResourceId, TagKeys; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("UntagResource", Dict{String, Any}("ResourceId"=>ResourceId, "TagKeys"=>TagKeys); aws_config=aws_config)
untag_resource(ResourceId, TagKeys, params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("UntagResource", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("ResourceId"=>ResourceId, "TagKeys"=>TagKeys), params)); aws_config=aws_config)

"""
    update_organizational_unit(organizational_unit_id)
    update_organizational_unit(organizational_unit_id, params::Dict{String,<:Any})

Renames the specified organizational unit (OU). The ID and ARN don't change. The child OUs
and accounts remain in place, and any attached policies of the OU remain attached. This
operation can be called only from the organization's management account.

# Arguments
- `organizational_unit_id`: The unique identifier (ID) of the OU that you want to rename.
  You can get the ID from the ListOrganizationalUnitsForParent operation. The regex pattern
  for an organizational unit ID string requires \"ou-\" followed by from 4 to 32 lowercase
  letters or digits (the ID of the root that contains the OU). This string is followed by a
  second \"-\" dash and from 8 to 32 additional lowercase letters or digits.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"Name"`: The new name that you want to assign to the OU. The regex pattern that is used
  to validate this parameter is a string of any of the characters in the ASCII character
  range.
"""
update_organizational_unit(OrganizationalUnitId; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("UpdateOrganizationalUnit", Dict{String, Any}("OrganizationalUnitId"=>OrganizationalUnitId); aws_config=aws_config)
update_organizational_unit(OrganizationalUnitId, params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("UpdateOrganizationalUnit", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("OrganizationalUnitId"=>OrganizationalUnitId), params)); aws_config=aws_config)

"""
    update_policy(policy_id)
    update_policy(policy_id, params::Dict{String,<:Any})

Updates an existing policy with a new name, description, or content. If you don't supply
any parameter, that value remains unchanged. You can't change a policy's type. This
operation can be called only from the organization's management account.

# Arguments
- `policy_id`: The unique identifier (ID) of the policy that you want to update. The regex
  pattern for a policy ID string requires \"p-\" followed by from 8 to 128 lowercase or
  uppercase letters, digits, or the underscore character (_).

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"Content"`: If provided, the new content for the policy. The text must be correctly
  formatted JSON that complies with the syntax for the policy's type. For more information,
  see Service Control Policy Syntax in the AWS Organizations User Guide.
- `"Description"`: If provided, the new description for the policy.
- `"Name"`: If provided, the new name for the policy. The regex pattern that is used to
  validate this parameter is a string of any of the characters in the ASCII character range.
"""
update_policy(PolicyId; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("UpdatePolicy", Dict{String, Any}("PolicyId"=>PolicyId); aws_config=aws_config)
update_policy(PolicyId, params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = organizations("UpdatePolicy", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("PolicyId"=>PolicyId), params)); aws_config=aws_config)
