# This file is auto-generated by AWSMetadata.jl
using AWS
using AWS.AWSServices: transfer
using AWS.Compat
using AWS.UUIDs

"""
    create_access(external_id, role, server_id)
    create_access(external_id, role, server_id, params::Dict{String,<:Any})

Used by administrators to choose which groups in the directory should have access to upload
and download files over the enabled protocols using Amazon Web Services Transfer Family.
For example, a Microsoft Active Directory might contain 50,000 users, but only a small
fraction might need the ability to transfer files to the server. An administrator can use
CreateAccess to limit the access to the correct set of users who need this ability.

# Arguments
- `external_id`: A unique identifier that is required to identify specific groups within
  your directory. The users of the group that you associate have access to your Amazon S3 or
  Amazon EFS resources over the enabled protocols using Amazon Web Services Transfer Family.
  If you know the group name, you can view the SID values by running the following command
  using Windows PowerShell.  Get-ADGroup -Filter {samAccountName -like \"YourGroupName*\"}
  -Properties * | Select SamAccountName,ObjectSid  In that command, replace YourGroupName
  with the name of your Active Directory group. The regex used to validate this parameter is
  a string of characters consisting of uppercase and lowercase alphanumeric characters with
  no spaces. You can also include underscores or any of the following characters: =,.@:/-
- `role`: Specifies the Amazon Resource Name (ARN) of the IAM role that controls your
  users' access to your Amazon S3 bucket or EFS file system. The policies attached to this
  role determine the level of access that you want to provide your users when transferring
  files into and out of your Amazon S3 bucket or EFS file system. The IAM role should also
  contain a trust relationship that allows the server to access your resources when servicing
  your users' transfer requests.
- `server_id`: A system-assigned unique identifier for a server instance. This is the
  specific server that you added your user to.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"HomeDirectory"`: The landing directory (folder) for a user when they log in to the
  server using the client. A HomeDirectory example is /bucket_name/home/mydirectory.
- `"HomeDirectoryMappings"`: Logical directory mappings that specify what Amazon S3 or
  Amazon EFS paths and keys should be visible to your user and how you want to make them
  visible. You must specify the Entry and Target pair, where Entry shows how the path is made
  visible and Target is the actual Amazon S3 or Amazon EFS path. If you only specify a
  target, it is displayed as is. You also must ensure that your Amazon Web Services Identity
  and Access Management (IAM) role provides access to paths in Target. This value can only be
  set when HomeDirectoryType is set to LOGICAL. The following is an Entry and Target pair
  example.  [ { \"Entry\": \"your-personal-report.pdf\", \"Target\":
  \"/bucket3/customized-reports/{transfer:UserName}.pdf\" } ]  In most cases, you can use
  this value instead of the scope-down policy to lock down your user to the designated home
  directory (\"chroot\"). To do this, you can set Entry to / and set Target to the
  HomeDirectory parameter value. The following is an Entry and Target pair example for
  chroot.  [ { \"Entry:\": \"/\", \"Target\": \"/bucket_name/home/mydirectory\" } ]   If the
  target of a logical directory entry does not exist in Amazon S3 or EFS, the entry is
  ignored. As a workaround, you can use the Amazon S3 API or EFS API to create 0 byte objects
  as place holders for your directory. If using the CLI, use the s3api or efsapi call instead
  of s3 or efs so you can use the put-object operation. For example, you use the following:
  aws s3api put-object --bucket bucketname --key path/to/folder/. Make sure that the end of
  the key name ends in a / for it to be considered a folder.
- `"HomeDirectoryType"`: The type of landing directory (folder) you want your users' home
  directory to be when they log into the server. If you set it to PATH, the user will see the
  absolute Amazon S3 bucket or EFS paths as is in their file transfer protocol clients. If
  you set it LOGICAL, you will need to provide mappings in the HomeDirectoryMappings for how
  you want to make Amazon S3 or EFS paths visible to your users.
- `"Policy"`: A scope-down policy for your user so that you can use the same IAM role
  across multiple users. This policy scopes down user access to portions of their Amazon S3
  bucket. Variables that you can use inside this policy include {Transfer:UserName},
  {Transfer:HomeDirectory}, and {Transfer:HomeBucket}.  This only applies when domain of
  ServerId is S3. Amazon EFS does not use scope-down policies. For scope-down policies,
  Amazon Web Services Transfer Family stores the policy as a JSON blob, instead of the Amazon
  Resource Name (ARN) of the policy. You save the policy as a JSON blob and pass it in the
  Policy argument. For an example of a scope-down policy, see Example scope-down policy. For
  more information, see AssumeRole in the Amazon Web Services Security Token Service API
  Reference.
- `"PosixProfile"`:
"""
create_access(ExternalId, Role, ServerId; aws_config::AbstractAWSConfig=global_aws_config()) = transfer("CreateAccess", Dict{String, Any}("ExternalId"=>ExternalId, "Role"=>Role, "ServerId"=>ServerId); aws_config=aws_config)
create_access(ExternalId, Role, ServerId, params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = transfer("CreateAccess", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("ExternalId"=>ExternalId, "Role"=>Role, "ServerId"=>ServerId), params)); aws_config=aws_config)

"""
    create_server()
    create_server(params::Dict{String,<:Any})

Instantiates an auto-scaling virtual server based on the selected file transfer protocol in
Amazon Web Services. When you make updates to your file transfer protocol-enabled server or
when you work with users, use the service-generated ServerId property that is assigned to
the newly created server.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"Certificate"`: The Amazon Resource Name (ARN) of the Amazon Web Services Certificate
  Manager (ACM) certificate. Required when Protocols is set to FTPS. To request a new public
  certificate, see Request a public certificate in the  Amazon Web Services Certificate
  Manager User Guide. To import an existing certificate into ACM, see Importing certificates
  into ACM in the  Amazon Web Services Certificate Manager User Guide. To request a private
  certificate to use FTPS through private IP addresses, see Request a private certificate in
  the  Amazon Web Services Certificate Manager User Guide. Certificates with the following
  cryptographic algorithms and key sizes are supported:   2048-bit RSA (RSA_2048)   4096-bit
  RSA (RSA_4096)   Elliptic Prime Curve 256 bit (EC_prime256v1)   Elliptic Prime Curve 384
  bit (EC_secp384r1)   Elliptic Prime Curve 521 bit (EC_secp521r1)    The certificate must be
  a valid SSL/TLS X.509 version 3 certificate with FQDN or IP address specified and
  information about the issuer.
- `"Domain"`: The domain of the storage system that is used for file transfers. There are
  two domains available: Amazon Simple Storage Service (Amazon S3) and Amazon Elastic File
  System (Amazon EFS). The default value is S3.  After the server is created, the domain
  cannot be changed.
- `"EndpointDetails"`: The virtual private cloud (VPC) endpoint settings that are
  configured for your server. When you host your endpoint within your VPC, you can make it
  accessible only to resources within your VPC, or you can attach Elastic IP addresses and
  make it accessible to clients over the internet. Your VPC's default security groups are
  automatically assigned to your endpoint.
- `"EndpointType"`: The type of endpoint that you want your server to use. You can choose
  to make your server's endpoint publicly accessible (PUBLIC) or host it inside your VPC.
  With an endpoint that is hosted in a VPC, you can restrict access to your server and
  resources only within your VPC or choose to make it internet facing by attaching Elastic IP
  addresses directly to it.   After May 19, 2021, you won't be able to create a server using
  EndpointType=VPC_ENDPOINT in your Amazon Web Services account if your account hasn't
  already done so before May 19, 2021. If you have already created servers with
  EndpointType=VPC_ENDPOINT in your Amazon Web Services account on or before May 19, 2021,
  you will not be affected. After this date, use EndpointType=VPC. For more information, see
  https://docs.aws.amazon.com/transfer/latest/userguide/create-server-in-vpc.html#deprecate-vp
  c-endpoint. It is recommended that you use VPC as the EndpointType. With this endpoint
  type, you have the option to directly associate up to three Elastic IPv4 addresses (BYO IP
  included) with your server's endpoint and use VPC security groups to restrict traffic by
  the client's public IP address. This is not possible with EndpointType set to VPC_ENDPOINT.
- `"HostKey"`: The RSA private key as generated by the ssh-keygen -N \"\" -m PEM -f
  my-new-server-key command.  If you aren't planning to migrate existing users from an
  existing SFTP-enabled server to a new server, don't update the host key. Accidentally
  changing a server's host key can be disruptive.  For more information, see Change the host
  key for your SFTP-enabled server in the Amazon Web Services Transfer Family User Guide.
- `"IdentityProviderDetails"`: Required when IdentityProviderType is set to
  AWS_DIRECTORY_SERVICE or API_GATEWAY. Accepts an array containing all of the information
  required to use a directory in AWS_DIRECTORY_SERVICE or invoke a customer-supplied
  authentication API, including the API Gateway URL. Not required when IdentityProviderType
  is set to SERVICE_MANAGED.
- `"IdentityProviderType"`: Specifies the mode of authentication for a server. The default
  value is SERVICE_MANAGED, which allows you to store and access user credentials within the
  Amazon Web Services Transfer Family service. Use AWS_DIRECTORY_SERVICE to provide access to
  Active Directory groups in Amazon Web Services Managed Active Directory or Microsoft Active
  Directory in your on-premises environment or in Amazon Web Services using AD Connectors.
  This option also requires you to provide a Directory ID using the IdentityProviderDetails
  parameter. Use the API_GATEWAY value to integrate with an identity provider of your
  choosing. The API_GATEWAY setting requires you to provide an API Gateway endpoint URL to
  call for authentication using the IdentityProviderDetails parameter.
- `"LoggingRole"`: Specifies the Amazon Resource Name (ARN) of the Amazon Web Services
  Identity and Access Management (IAM) role that allows a server to turn on Amazon CloudWatch
  logging for Amazon S3 or Amazon EFS events. When set, user activity can be viewed in your
  CloudWatch logs.
- `"Protocols"`: Specifies the file transfer protocol or protocols over which your file
  transfer protocol client can connect to your server's endpoint. The available protocols
  are:    SFTP (Secure Shell (SSH) File Transfer Protocol): File transfer over SSH    FTPS
  (File Transfer Protocol Secure): File transfer with TLS encryption    FTP (File Transfer
  Protocol): Unencrypted file transfer    If you select FTPS, you must choose a certificate
  stored in Amazon Web Services Certificate Manager (ACM) which is used to identify your
  server when clients connect to it over FTPS. If Protocol includes either FTP or FTPS, then
  the EndpointType must be VPC and the IdentityProviderType must be AWS_DIRECTORY_SERVICE or
  API_GATEWAY. If Protocol includes FTP, then AddressAllocationIds cannot be associated. If
  Protocol is set only to SFTP, the EndpointType can be set to PUBLIC and the
  IdentityProviderType can be set to SERVICE_MANAGED.
- `"SecurityPolicyName"`: Specifies the name of the security policy that is attached to the
  server.
- `"Tags"`: Key-value pairs that can be used to group and search for servers.
"""
create_server(; aws_config::AbstractAWSConfig=global_aws_config()) = transfer("CreateServer"; aws_config=aws_config)
create_server(params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = transfer("CreateServer", params; aws_config=aws_config)

"""
    create_user(role, server_id, user_name)
    create_user(role, server_id, user_name, params::Dict{String,<:Any})

Creates a user and associates them with an existing file transfer protocol-enabled server.
You can only create and associate users with servers that have the IdentityProviderType set
to SERVICE_MANAGED. Using parameters for CreateUser, you can specify the user name, set the
home directory, store the user's public key, and assign the user's Amazon Web Services
Identity and Access Management (IAM) role. You can also optionally add a scope-down policy,
and assign metadata with tags that can be used to group and search for users.

# Arguments
- `role`: Specifies the Amazon Resource Name (ARN) of the IAM role that controls your
  users' access to your Amazon S3 bucket or EFS file system. The policies attached to this
  role determine the level of access that you want to provide your users when transferring
  files into and out of your Amazon S3 bucket or EFS file system. The IAM role should also
  contain a trust relationship that allows the server to access your resources when servicing
  your users' transfer requests.
- `server_id`: A system-assigned unique identifier for a server instance. This is the
  specific server that you added your user to.
- `user_name`: A unique string that identifies a user and is associated with a as specified
  by the ServerId. This user name must be a minimum of 3 and a maximum of 100 characters
  long. The following are valid characters: a-z, A-Z, 0-9, underscore '_', hyphen '-', period
  '.', and at sign '@'. The user name can't start with a hyphen, period, or at sign.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"HomeDirectory"`: The landing directory (folder) for a user when they log in to the
  server using the client. A HomeDirectory example is /bucket_name/home/mydirectory.
- `"HomeDirectoryMappings"`: Logical directory mappings that specify what Amazon S3 or
  Amazon EFS paths and keys should be visible to your user and how you want to make them
  visible. You must specify the Entry and Target pair, where Entry shows how the path is made
  visible and Target is the actual Amazon S3 or Amazon EFS path. If you only specify a
  target, it is displayed as is. You also must ensure that your Amazon Web Services Identity
  and Access Management (IAM) role provides access to paths in Target. This value can only be
  set when HomeDirectoryType is set to LOGICAL. The following is an Entry and Target pair
  example.  [ { \"Entry\": \"your-personal-report.pdf\", \"Target\":
  \"/bucket3/customized-reports/{transfer:UserName}.pdf\" } ]  In most cases, you can use
  this value instead of the scope-down policy to lock your user down to the designated home
  directory (\"chroot\"). To do this, you can set Entry to / and set Target to the
  HomeDirectory parameter value. The following is an Entry and Target pair example for
  chroot.  [ { \"Entry:\": \"/\", \"Target\": \"/bucket_name/home/mydirectory\" } ]   If the
  target of a logical directory entry does not exist in Amazon S3 or EFS, the entry is
  ignored. As a workaround, you can use the Amazon S3 API or EFS API to create 0 byte objects
  as place holders for your directory. If using the CLI, use the s3api or efsapi call instead
  of s3 or efs so you can use the put-object operation. For example, you use the following:
  aws s3api put-object --bucket bucketname --key path/to/folder/. Make sure that the end of
  the key name ends in a / for it to be considered a folder.
- `"HomeDirectoryType"`: The type of landing directory (folder) you want your users' home
  directory to be when they log into the server. If you set it to PATH, the user will see the
  absolute Amazon S3 bucket or EFS paths as is in their file transfer protocol clients. If
  you set it LOGICAL, you will need to provide mappings in the HomeDirectoryMappings for how
  you want to make Amazon S3 or EFS paths visible to your users.
- `"Policy"`: A scope-down policy for your user so that you can use the same IAM role
  across multiple users. This policy scopes down user access to portions of their Amazon S3
  bucket. Variables that you can use inside this policy include {Transfer:UserName},
  {Transfer:HomeDirectory}, and {Transfer:HomeBucket}.  This only applies when domain of
  ServerId is S3. EFS does not use scope down policy. For scope-down policies, Amazon Web
  Services Transfer Family stores the policy as a JSON blob, instead of the Amazon Resource
  Name (ARN) of the policy. You save the policy as a JSON blob and pass it in the Policy
  argument. For an example of a scope-down policy, see Example scope-down policy. For more
  information, see AssumeRole in the Amazon Web Services Security Token Service API
  Reference.
- `"PosixProfile"`: Specifies the full POSIX identity, including user ID (Uid), group ID
  (Gid), and any secondary groups IDs (SecondaryGids), that controls your users' access to
  your Amazon EFS file systems. The POSIX permissions that are set on files and directories
  in Amazon EFS determine the level of access your users get when transferring files into and
  out of your Amazon EFS file systems.
- `"SshPublicKeyBody"`: The public portion of the Secure Shell (SSH) key used to
  authenticate the user to the server.
- `"Tags"`: Key-value pairs that can be used to group and search for users. Tags are
  metadata attached to users for any purpose.
"""
create_user(Role, ServerId, UserName; aws_config::AbstractAWSConfig=global_aws_config()) = transfer("CreateUser", Dict{String, Any}("Role"=>Role, "ServerId"=>ServerId, "UserName"=>UserName); aws_config=aws_config)
create_user(Role, ServerId, UserName, params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = transfer("CreateUser", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("Role"=>Role, "ServerId"=>ServerId, "UserName"=>UserName), params)); aws_config=aws_config)

"""
    delete_access(external_id, server_id)
    delete_access(external_id, server_id, params::Dict{String,<:Any})

Allows you to delete the access specified in the ServerID and ExternalID parameters.

# Arguments
- `external_id`: A unique identifier that is required to identify specific groups within
  your directory. The users of the group that you associate have access to your Amazon S3 or
  Amazon EFS resources over the enabled protocols using Amazon Web Services Transfer Family.
  If you know the group name, you can view the SID values by running the following command
  using Windows PowerShell.  Get-ADGroup -Filter {samAccountName -like \"YourGroupName*\"}
  -Properties * | Select SamAccountName,ObjectSid  In that command, replace YourGroupName
  with the name of your Active Directory group. The regex used to validate this parameter is
  a string of characters consisting of uppercase and lowercase alphanumeric characters with
  no spaces. You can also include underscores or any of the following characters: =,.@:/-
- `server_id`: A system-assigned unique identifier for a server that has this user assigned.

"""
delete_access(ExternalId, ServerId; aws_config::AbstractAWSConfig=global_aws_config()) = transfer("DeleteAccess", Dict{String, Any}("ExternalId"=>ExternalId, "ServerId"=>ServerId); aws_config=aws_config)
delete_access(ExternalId, ServerId, params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = transfer("DeleteAccess", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("ExternalId"=>ExternalId, "ServerId"=>ServerId), params)); aws_config=aws_config)

"""
    delete_server(server_id)
    delete_server(server_id, params::Dict{String,<:Any})

Deletes the file transfer protocol-enabled server that you specify. No response returns
from this operation.

# Arguments
- `server_id`: A unique system-assigned identifier for a server instance.

"""
delete_server(ServerId; aws_config::AbstractAWSConfig=global_aws_config()) = transfer("DeleteServer", Dict{String, Any}("ServerId"=>ServerId); aws_config=aws_config)
delete_server(ServerId, params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = transfer("DeleteServer", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("ServerId"=>ServerId), params)); aws_config=aws_config)

"""
    delete_ssh_public_key(server_id, ssh_public_key_id, user_name)
    delete_ssh_public_key(server_id, ssh_public_key_id, user_name, params::Dict{String,<:Any})

Deletes a user's Secure Shell (SSH) public key. No response is returned from this operation.

# Arguments
- `server_id`: A system-assigned unique identifier for a file transfer protocol-enabled
  server instance that has the user assigned to it.
- `ssh_public_key_id`: A unique identifier used to reference your user's specific SSH key.
- `user_name`: A unique string that identifies a user whose public key is being deleted.

"""
delete_ssh_public_key(ServerId, SshPublicKeyId, UserName; aws_config::AbstractAWSConfig=global_aws_config()) = transfer("DeleteSshPublicKey", Dict{String, Any}("ServerId"=>ServerId, "SshPublicKeyId"=>SshPublicKeyId, "UserName"=>UserName); aws_config=aws_config)
delete_ssh_public_key(ServerId, SshPublicKeyId, UserName, params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = transfer("DeleteSshPublicKey", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("ServerId"=>ServerId, "SshPublicKeyId"=>SshPublicKeyId, "UserName"=>UserName), params)); aws_config=aws_config)

"""
    delete_user(server_id, user_name)
    delete_user(server_id, user_name, params::Dict{String,<:Any})

Deletes the user belonging to a file transfer protocol-enabled server you specify. No
response returns from this operation.  When you delete a user from a server, the user's
information is lost.

# Arguments
- `server_id`: A system-assigned unique identifier for a server instance that has the user
  assigned to it.
- `user_name`: A unique string that identifies a user that is being deleted from a server.

"""
delete_user(ServerId, UserName; aws_config::AbstractAWSConfig=global_aws_config()) = transfer("DeleteUser", Dict{String, Any}("ServerId"=>ServerId, "UserName"=>UserName); aws_config=aws_config)
delete_user(ServerId, UserName, params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = transfer("DeleteUser", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("ServerId"=>ServerId, "UserName"=>UserName), params)); aws_config=aws_config)

"""
    describe_access(external_id, server_id)
    describe_access(external_id, server_id, params::Dict{String,<:Any})

Describes the access that is assigned to the specific file transfer protocol-enabled
server, as identified by its ServerId property and its ExternalID. The response from this
call returns the properties of the access that is associated with the ServerId value that
was specified.

# Arguments
- `external_id`: A unique identifier that is required to identify specific groups within
  your directory. The users of the group that you associate have access to your Amazon S3 or
  Amazon EFS resources over the enabled protocols using Amazon Web Services Transfer Family.
  If you know the group name, you can view the SID values by running the following command
  using Windows PowerShell.  Get-ADGroup -Filter {samAccountName -like \"YourGroupName*\"}
  -Properties * | Select SamAccountName,ObjectSid  In that command, replace YourGroupName
  with the name of your Active Directory group. The regex used to validate this parameter is
  a string of characters consisting of uppercase and lowercase alphanumeric characters with
  no spaces. You can also include underscores or any of the following characters: =,.@:/-
- `server_id`: A system-assigned unique identifier for a server that has this access
  assigned.

"""
describe_access(ExternalId, ServerId; aws_config::AbstractAWSConfig=global_aws_config()) = transfer("DescribeAccess", Dict{String, Any}("ExternalId"=>ExternalId, "ServerId"=>ServerId); aws_config=aws_config)
describe_access(ExternalId, ServerId, params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = transfer("DescribeAccess", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("ExternalId"=>ExternalId, "ServerId"=>ServerId), params)); aws_config=aws_config)

"""
    describe_security_policy(security_policy_name)
    describe_security_policy(security_policy_name, params::Dict{String,<:Any})

Describes the security policy that is attached to your file transfer protocol-enabled
server. The response contains a description of the security policy's properties. For more
information about security policies, see Working with security policies.

# Arguments
- `security_policy_name`: Specifies the name of the security policy that is attached to the
  server.

"""
describe_security_policy(SecurityPolicyName; aws_config::AbstractAWSConfig=global_aws_config()) = transfer("DescribeSecurityPolicy", Dict{String, Any}("SecurityPolicyName"=>SecurityPolicyName); aws_config=aws_config)
describe_security_policy(SecurityPolicyName, params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = transfer("DescribeSecurityPolicy", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("SecurityPolicyName"=>SecurityPolicyName), params)); aws_config=aws_config)

"""
    describe_server(server_id)
    describe_server(server_id, params::Dict{String,<:Any})

Describes a file transfer protocol-enabled server that you specify by passing the ServerId
parameter. The response contains a description of a server's properties. When you set
EndpointType to VPC, the response will contain the EndpointDetails.

# Arguments
- `server_id`: A system-assigned unique identifier for a server.

"""
describe_server(ServerId; aws_config::AbstractAWSConfig=global_aws_config()) = transfer("DescribeServer", Dict{String, Any}("ServerId"=>ServerId); aws_config=aws_config)
describe_server(ServerId, params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = transfer("DescribeServer", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("ServerId"=>ServerId), params)); aws_config=aws_config)

"""
    describe_user(server_id, user_name)
    describe_user(server_id, user_name, params::Dict{String,<:Any})

Describes the user assigned to the specific file transfer protocol-enabled server, as
identified by its ServerId property. The response from this call returns the properties of
the user associated with the ServerId value that was specified.

# Arguments
- `server_id`: A system-assigned unique identifier for a server that has this user assigned.
- `user_name`: The name of the user assigned to one or more servers. User names are part of
  the sign-in credentials to use the Amazon Web Services Transfer Family service and perform
  file transfer tasks.

"""
describe_user(ServerId, UserName; aws_config::AbstractAWSConfig=global_aws_config()) = transfer("DescribeUser", Dict{String, Any}("ServerId"=>ServerId, "UserName"=>UserName); aws_config=aws_config)
describe_user(ServerId, UserName, params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = transfer("DescribeUser", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("ServerId"=>ServerId, "UserName"=>UserName), params)); aws_config=aws_config)

"""
    import_ssh_public_key(server_id, ssh_public_key_body, user_name)
    import_ssh_public_key(server_id, ssh_public_key_body, user_name, params::Dict{String,<:Any})

Adds a Secure Shell (SSH) public key to a user account identified by a UserName value
assigned to the specific file transfer protocol-enabled server, identified by ServerId. The
response returns the UserName value, the ServerId value, and the name of the SshPublicKeyId.

# Arguments
- `server_id`: A system-assigned unique identifier for a server.
- `ssh_public_key_body`: The public key portion of an SSH key pair.
- `user_name`: The name of the user account that is assigned to one or more servers.

"""
import_ssh_public_key(ServerId, SshPublicKeyBody, UserName; aws_config::AbstractAWSConfig=global_aws_config()) = transfer("ImportSshPublicKey", Dict{String, Any}("ServerId"=>ServerId, "SshPublicKeyBody"=>SshPublicKeyBody, "UserName"=>UserName); aws_config=aws_config)
import_ssh_public_key(ServerId, SshPublicKeyBody, UserName, params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = transfer("ImportSshPublicKey", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("ServerId"=>ServerId, "SshPublicKeyBody"=>SshPublicKeyBody, "UserName"=>UserName), params)); aws_config=aws_config)

"""
    list_accesses(server_id)
    list_accesses(server_id, params::Dict{String,<:Any})

Lists the details for all the accesses you have on your server.

# Arguments
- `server_id`: A system-assigned unique identifier for a server that has users assigned to
  it.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"MaxResults"`: Specifies the maximum number of access SIDs to return.
- `"NextToken"`: When you can get additional results from the ListAccesses call, a
  NextToken parameter is returned in the output. You can then pass in a subsequent command to
  the NextToken parameter to continue listing additional accesses.
"""
list_accesses(ServerId; aws_config::AbstractAWSConfig=global_aws_config()) = transfer("ListAccesses", Dict{String, Any}("ServerId"=>ServerId); aws_config=aws_config)
list_accesses(ServerId, params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = transfer("ListAccesses", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("ServerId"=>ServerId), params)); aws_config=aws_config)

"""
    list_security_policies()
    list_security_policies(params::Dict{String,<:Any})

Lists the security policies that are attached to your file transfer protocol-enabled
servers.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"MaxResults"`: Specifies the number of security policies to return as a response to the
  ListSecurityPolicies query.
- `"NextToken"`: When additional results are obtained from the ListSecurityPolicies
  command, a NextToken parameter is returned in the output. You can then pass the NextToken
  parameter in a subsequent command to continue listing additional security policies.
"""
list_security_policies(; aws_config::AbstractAWSConfig=global_aws_config()) = transfer("ListSecurityPolicies"; aws_config=aws_config)
list_security_policies(params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = transfer("ListSecurityPolicies", params; aws_config=aws_config)

"""
    list_servers()
    list_servers(params::Dict{String,<:Any})

Lists the file transfer protocol-enabled servers that are associated with your Amazon Web
Services account.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"MaxResults"`: Specifies the number of servers to return as a response to the
  ListServers query.
- `"NextToken"`: When additional results are obtained from the ListServers command, a
  NextToken parameter is returned in the output. You can then pass the NextToken parameter in
  a subsequent command to continue listing additional servers.
"""
list_servers(; aws_config::AbstractAWSConfig=global_aws_config()) = transfer("ListServers"; aws_config=aws_config)
list_servers(params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = transfer("ListServers", params; aws_config=aws_config)

"""
    list_tags_for_resource(arn)
    list_tags_for_resource(arn, params::Dict{String,<:Any})

Lists all of the tags associated with the Amazon Resource Name (ARN) that you specify. The
resource can be a user, server, or role.

# Arguments
- `arn`: Requests the tags associated with a particular Amazon Resource Name (ARN). An ARN
  is an identifier for a specific Amazon Web Services resource, such as a server, user, or
  role.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"MaxResults"`: Specifies the number of tags to return as a response to the
  ListTagsForResource request.
- `"NextToken"`: When you request additional results from the ListTagsForResource
  operation, a NextToken parameter is returned in the input. You can then pass in a
  subsequent command to the NextToken parameter to continue listing additional tags.
"""
list_tags_for_resource(Arn; aws_config::AbstractAWSConfig=global_aws_config()) = transfer("ListTagsForResource", Dict{String, Any}("Arn"=>Arn); aws_config=aws_config)
list_tags_for_resource(Arn, params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = transfer("ListTagsForResource", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("Arn"=>Arn), params)); aws_config=aws_config)

"""
    list_users(server_id)
    list_users(server_id, params::Dict{String,<:Any})

Lists the users for a file transfer protocol-enabled server that you specify by passing the
ServerId parameter.

# Arguments
- `server_id`: A system-assigned unique identifier for a server that has users assigned to
  it.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"MaxResults"`: Specifies the number of users to return as a response to the ListUsers
  request.
- `"NextToken"`: When you can get additional results from the ListUsers call, a NextToken
  parameter is returned in the output. You can then pass in a subsequent command to the
  NextToken parameter to continue listing additional users.
"""
list_users(ServerId; aws_config::AbstractAWSConfig=global_aws_config()) = transfer("ListUsers", Dict{String, Any}("ServerId"=>ServerId); aws_config=aws_config)
list_users(ServerId, params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = transfer("ListUsers", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("ServerId"=>ServerId), params)); aws_config=aws_config)

"""
    start_server(server_id)
    start_server(server_id, params::Dict{String,<:Any})

Changes the state of a file transfer protocol-enabled server from OFFLINE to ONLINE. It has
no impact on a server that is already ONLINE. An ONLINE server can accept and process file
transfer jobs. The state of STARTING indicates that the server is in an intermediate state,
either not fully able to respond, or not fully online. The values of START_FAILED can
indicate an error condition. No response is returned from this call.

# Arguments
- `server_id`: A system-assigned unique identifier for a server that you start.

"""
start_server(ServerId; aws_config::AbstractAWSConfig=global_aws_config()) = transfer("StartServer", Dict{String, Any}("ServerId"=>ServerId); aws_config=aws_config)
start_server(ServerId, params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = transfer("StartServer", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("ServerId"=>ServerId), params)); aws_config=aws_config)

"""
    stop_server(server_id)
    stop_server(server_id, params::Dict{String,<:Any})

Changes the state of a file transfer protocol-enabled server from ONLINE to OFFLINE. An
OFFLINE server cannot accept and process file transfer jobs. Information tied to your
server, such as server and user properties, are not affected by stopping your server.
Stopping the server will not reduce or impact your file transfer protocol endpoint billing;
you must delete the server to stop being billed.  The state of STOPPING indicates that the
server is in an intermediate state, either not fully able to respond, or not fully offline.
The values of STOP_FAILED can indicate an error condition. No response is returned from
this call.

# Arguments
- `server_id`: A system-assigned unique identifier for a server that you stopped.

"""
stop_server(ServerId; aws_config::AbstractAWSConfig=global_aws_config()) = transfer("StopServer", Dict{String, Any}("ServerId"=>ServerId); aws_config=aws_config)
stop_server(ServerId, params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = transfer("StopServer", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("ServerId"=>ServerId), params)); aws_config=aws_config)

"""
    tag_resource(arn, tags)
    tag_resource(arn, tags, params::Dict{String,<:Any})

Attaches a key-value pair to a resource, as identified by its Amazon Resource Name (ARN).
Resources are users, servers, roles, and other entities. There is no response returned from
this call.

# Arguments
- `arn`: An Amazon Resource Name (ARN) for a specific Amazon Web Services resource, such as
  a server, user, or role.
- `tags`: Key-value pairs assigned to ARNs that you can use to group and search for
  resources by type. You can attach this metadata to user accounts for any purpose.

"""
tag_resource(Arn, Tags; aws_config::AbstractAWSConfig=global_aws_config()) = transfer("TagResource", Dict{String, Any}("Arn"=>Arn, "Tags"=>Tags); aws_config=aws_config)
tag_resource(Arn, Tags, params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = transfer("TagResource", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("Arn"=>Arn, "Tags"=>Tags), params)); aws_config=aws_config)

"""
    test_identity_provider(server_id, user_name)
    test_identity_provider(server_id, user_name, params::Dict{String,<:Any})

If the IdentityProviderType of a file transfer protocol-enabled server is
AWS_DIRECTORY_SERVICE or API_Gateway, tests whether your identity provider is set up
successfully. We highly recommend that you call this operation to test your authentication
method as soon as you create your server. By doing so, you can troubleshoot issues with the
identity provider integration to ensure that your users can successfully use the service.

# Arguments
- `server_id`: A system-assigned identifier for a specific server. That server's user
  authentication method is tested with a user name and password.
- `user_name`: The name of the user account to be tested.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"ServerProtocol"`: The type of file transfer protocol to be tested. The available
  protocols are:   Secure Shell (SSH) File Transfer Protocol (SFTP)   File Transfer Protocol
  Secure (FTPS)   File Transfer Protocol (FTP)
- `"SourceIp"`: The source IP address of the user account to be tested.
- `"UserPassword"`: The password of the user account to be tested.
"""
test_identity_provider(ServerId, UserName; aws_config::AbstractAWSConfig=global_aws_config()) = transfer("TestIdentityProvider", Dict{String, Any}("ServerId"=>ServerId, "UserName"=>UserName); aws_config=aws_config)
test_identity_provider(ServerId, UserName, params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = transfer("TestIdentityProvider", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("ServerId"=>ServerId, "UserName"=>UserName), params)); aws_config=aws_config)

"""
    untag_resource(arn, tag_keys)
    untag_resource(arn, tag_keys, params::Dict{String,<:Any})

Detaches a key-value pair from a resource, as identified by its Amazon Resource Name (ARN).
Resources are users, servers, roles, and other entities. No response is returned from this
call.

# Arguments
- `arn`: The value of the resource that will have the tag removed. An Amazon Resource Name
  (ARN) is an identifier for a specific Amazon Web Services resource, such as a server, user,
  or role.
- `tag_keys`: TagKeys are key-value pairs assigned to ARNs that can be used to group and
  search for resources by type. This metadata can be attached to resources for any purpose.

"""
untag_resource(Arn, TagKeys; aws_config::AbstractAWSConfig=global_aws_config()) = transfer("UntagResource", Dict{String, Any}("Arn"=>Arn, "TagKeys"=>TagKeys); aws_config=aws_config)
untag_resource(Arn, TagKeys, params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = transfer("UntagResource", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("Arn"=>Arn, "TagKeys"=>TagKeys), params)); aws_config=aws_config)

"""
    update_access(external_id, server_id)
    update_access(external_id, server_id, params::Dict{String,<:Any})

Allows you to update parameters for the access specified in the ServerID and ExternalID
parameters.

# Arguments
- `external_id`: A unique identifier that is required to identify specific groups within
  your directory. The users of the group that you associate have access to your Amazon S3 or
  Amazon EFS resources over the enabled protocols using Amazon Web Services Transfer Family.
  If you know the group name, you can view the SID values by running the following command
  using Windows PowerShell.  Get-ADGroup -Filter {samAccountName -like \"YourGroupName*\"}
  -Properties * | Select SamAccountName,ObjectSid  In that command, replace YourGroupName
  with the name of your Active Directory group. The regex used to validate this parameter is
  a string of characters consisting of uppercase and lowercase alphanumeric characters with
  no spaces. You can also include underscores or any of the following characters: =,.@:/-
- `server_id`: A system-assigned unique identifier for a server instance. This is the
  specific server that you added your user to.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"HomeDirectory"`: The landing directory (folder) for a user when they log in to the
  server using the client. A HomeDirectory example is /bucket_name/home/mydirectory.
- `"HomeDirectoryMappings"`: Logical directory mappings that specify what Amazon S3 or
  Amazon EFS paths and keys should be visible to your user and how you want to make them
  visible. You must specify the Entry and Target pair, where Entry shows how the path is made
  visible and Target is the actual Amazon S3 or Amazon EFS path. If you only specify a
  target, it is displayed as is. You also must ensure that your Amazon Web Services Identity
  and Access Management (IAM) role provides access to paths in Target. This value can only be
  set when HomeDirectoryType is set to LOGICAL. The following is an Entry and Target pair
  example.  [ { \"Entry\": \"your-personal-report.pdf\", \"Target\":
  \"/bucket3/customized-reports/{transfer:UserName}.pdf\" } ]  In most cases, you can use
  this value instead of the scope-down policy to lock down your user to the designated home
  directory (\"chroot\"). To do this, you can set Entry to / and set Target to the
  HomeDirectory parameter value. The following is an Entry and Target pair example for
  chroot.  [ { \"Entry:\": \"/\", \"Target\": \"/bucket_name/home/mydirectory\" } ]   If the
  target of a logical directory entry does not exist in Amazon S3 or EFS, the entry is
  ignored. As a workaround, you can use the Amazon S3 API or EFS API to create 0 byte objects
  as place holders for your directory. If using the CLI, use the s3api or efsapi call instead
  of s3 or efs so you can use the put-object operation. For example, you use the following:
  aws s3api put-object --bucket bucketname --key path/to/folder/. Make sure that the end of
  the key name ends in a / for it to be considered a folder.
- `"HomeDirectoryType"`: The type of landing directory (folder) you want your users' home
  directory to be when they log into the server. If you set it to PATH, the user will see the
  absolute Amazon S3 bucket or EFS paths as is in their file transfer protocol clients. If
  you set it LOGICAL, you will need to provide mappings in the HomeDirectoryMappings for how
  you want to make Amazon S3 or EFS paths visible to your users.
- `"Policy"`: A scope-down policy for your user so that you can use the same IAM role
  across multiple users. This policy scopes down user access to portions of their Amazon S3
  bucket. Variables that you can use inside this policy include {Transfer:UserName},
  {Transfer:HomeDirectory}, and {Transfer:HomeBucket}.  This only applies when domain of
  ServerId is S3. Amazon EFS does not use scope down policy. For scope-down policies, Amazon
  Web ServicesTransfer Family stores the policy as a JSON blob, instead of the Amazon
  Resource Name (ARN) of the policy. You save the policy as a JSON blob and pass it in the
  Policy argument. For an example of a scope-down policy, see Example scope-down policy. For
  more information, see AssumeRole in the Amazon Web ServicesSecurity Token Service API
  Reference.
- `"PosixProfile"`:
- `"Role"`: Specifies the Amazon Resource Name (ARN) of the IAM role that controls your
  users' access to your Amazon S3 bucket or EFS file system. The policies attached to this
  role determine the level of access that you want to provide your users when transferring
  files into and out of your Amazon S3 bucket or EFS file system. The IAM role should also
  contain a trust relationship that allows the server to access your resources when servicing
  your users' transfer requests.
"""
update_access(ExternalId, ServerId; aws_config::AbstractAWSConfig=global_aws_config()) = transfer("UpdateAccess", Dict{String, Any}("ExternalId"=>ExternalId, "ServerId"=>ServerId); aws_config=aws_config)
update_access(ExternalId, ServerId, params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = transfer("UpdateAccess", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("ExternalId"=>ExternalId, "ServerId"=>ServerId), params)); aws_config=aws_config)

"""
    update_server(server_id)
    update_server(server_id, params::Dict{String,<:Any})

Updates the file transfer protocol-enabled server's properties after that server has been
created. The UpdateServer call returns the ServerId of the server you updated.

# Arguments
- `server_id`: A system-assigned unique identifier for a server instance that the user
  account is assigned to.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"Certificate"`: The Amazon Resource Name (ARN) of the Amazon Web ServicesCertificate
  Manager (ACM) certificate. Required when Protocols is set to FTPS. To request a new public
  certificate, see Request a public certificate in the  Amazon Web ServicesCertificate
  Manager User Guide. To import an existing certificate into ACM, see Importing certificates
  into ACM in the  Amazon Web ServicesCertificate Manager User Guide. To request a private
  certificate to use FTPS through private IP addresses, see Request a private certificate in
  the  Amazon Web ServicesCertificate Manager User Guide. Certificates with the following
  cryptographic algorithms and key sizes are supported:   2048-bit RSA (RSA_2048)   4096-bit
  RSA (RSA_4096)   Elliptic Prime Curve 256 bit (EC_prime256v1)   Elliptic Prime Curve 384
  bit (EC_secp384r1)   Elliptic Prime Curve 521 bit (EC_secp521r1)    The certificate must be
  a valid SSL/TLS X.509 version 3 certificate with FQDN or IP address specified and
  information about the issuer.
- `"EndpointDetails"`: The virtual private cloud (VPC) endpoint settings that are
  configured for your server. When you host your endpoint within your VPC, you can make it
  accessible only to resources within your VPC, or you can attach Elastic IP addresses and
  make it accessible to clients over the internet. Your VPC's default security groups are
  automatically assigned to your endpoint.
- `"EndpointType"`: The type of endpoint that you want your server to use. You can choose
  to make your server's endpoint publicly accessible (PUBLIC) or host it inside your VPC.
  With an endpoint that is hosted in a VPC, you can restrict access to your server and
  resources only within your VPC or choose to make it internet facing by attaching Elastic IP
  addresses directly to it.   After May 19, 2021, you won't be able to create a server using
  EndpointType=VPC_ENDPOINT in your Amazon Web Servicesaccount if your account hasn't already
  done so before May 19, 2021. If you have already created servers with
  EndpointType=VPC_ENDPOINT in your Amazon Web Servicesaccount on or before May 19, 2021, you
  will not be affected. After this date, use EndpointType=VPC. For more information, see
  https://docs.aws.amazon.com/transfer/latest/userguide/create-server-in-vpc.html#deprecate-vp
  c-endpoint. It is recommended that you use VPC as the EndpointType. With this endpoint
  type, you have the option to directly associate up to three Elastic IPv4 addresses (BYO IP
  included) with your server's endpoint and use VPC security groups to restrict traffic by
  the client's public IP address. This is not possible with EndpointType set to VPC_ENDPOINT.
- `"HostKey"`: The RSA private key as generated by ssh-keygen -N \"\" -m PEM -f
  my-new-server-key.  If you aren't planning to migrate existing users from an existing
  server to a new server, don't update the host key. Accidentally changing a server's host
  key can be disruptive.  For more information, see Change the host key for your SFTP-enabled
  server in the Amazon Web ServicesTransfer Family User Guide.
- `"IdentityProviderDetails"`: An array containing all of the information required to call
  a customer's authentication API method.
- `"LoggingRole"`: Specifies the Amazon Resource Name (ARN) of the Amazon Web Services
  Identity and Access Management (IAM) role that allows a server to turn on Amazon CloudWatch
  logging for Amazon S3 or Amazon EFS events. When set, user activity can be viewed in your
  CloudWatch logs.
- `"ProtocolDetails"`:  The protocol settings that are configured for your server.   Use
  the PassiveIp parameter to indicate passive mode (for FTP and FTPS protocols). Enter a
  single dotted-quad IPv4 address, such as the external IP address of a firewall, router, or
  load balancer.
- `"Protocols"`: Specifies the file transfer protocol or protocols over which your file
  transfer protocol client can connect to your server's endpoint. The available protocols
  are:   Secure Shell (SSH) File Transfer Protocol (SFTP): File transfer over SSH   File
  Transfer Protocol Secure (FTPS): File transfer with TLS encryption   File Transfer Protocol
  (FTP): Unencrypted file transfer    If you select FTPS, you must choose a certificate
  stored in Amazon Web ServicesCertificate Manager (ACM) which will be used to identify your
  server when clients connect to it over FTPS. If Protocol includes either FTP or FTPS, then
  the EndpointType must be VPC and the IdentityProviderType must be AWS_DIRECTORY_SERVICE or
  API_GATEWAY. If Protocol includes FTP, then AddressAllocationIds cannot be associated. If
  Protocol is set only to SFTP, the EndpointType can be set to PUBLIC and the
  IdentityProviderType can be set to SERVICE_MANAGED.
- `"SecurityPolicyName"`: Specifies the name of the security policy that is attached to the
  server.
"""
update_server(ServerId; aws_config::AbstractAWSConfig=global_aws_config()) = transfer("UpdateServer", Dict{String, Any}("ServerId"=>ServerId); aws_config=aws_config)
update_server(ServerId, params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = transfer("UpdateServer", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("ServerId"=>ServerId), params)); aws_config=aws_config)

"""
    update_user(server_id, user_name)
    update_user(server_id, user_name, params::Dict{String,<:Any})

Assigns new properties to a user. Parameters you pass modify any or all of the following:
the home directory, role, and policy for the UserName and ServerId you specify. The
response returns the ServerId and the UserName for the updated user.

# Arguments
- `server_id`: A system-assigned unique identifier for a server instance that the user
  account is assigned to.
- `user_name`: A unique string that identifies a user and is associated with a server as
  specified by the ServerId. This user name must be a minimum of 3 and a maximum of 100
  characters long. The following are valid characters: a-z, A-Z, 0-9, underscore '_', hyphen
  '-', period '.', and at sign '@'. The user name can't start with a hyphen, period, or at
  sign.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"HomeDirectory"`: The landing directory (folder) for a user when they log in to the
  server using the client. A HomeDirectory example is /bucket_name/home/mydirectory.
- `"HomeDirectoryMappings"`: Logical directory mappings that specify what Amazon S3 or
  Amazon EFS paths and keys should be visible to your user and how you want to make them
  visible. You must specify the Entry and Target pair, where Entry shows how the path is made
  visible and Target is the actual Amazon S3 or Amazon EFS path. If you only specify a
  target, it is displayed as is. You also must ensure that your Amazon Web Services Identity
  and Access Management (IAM) role provides access to paths in Target. This value can only be
  set when HomeDirectoryType is set to LOGICAL. The following is an Entry and Target pair
  example.  [ { \"Entry\": \"your-personal-report.pdf\", \"Target\":
  \"/bucket3/customized-reports/{transfer:UserName}.pdf\" } ]  In most cases, you can use
  this value instead of the scope-down policy to lock down your user to the designated home
  directory (\"chroot\"). To do this, you can set Entry to '/' and set Target to the
  HomeDirectory parameter value. The following is an Entry and Target pair example for
  chroot.  [ { \"Entry:\": \"/\", \"Target\": \"/bucket_name/home/mydirectory\" } ]   If the
  target of a logical directory entry does not exist in Amazon S3 or EFS, the entry is
  ignored. As a workaround, you can use the Amazon S3 API or EFS API to create 0 byte objects
  as place holders for your directory. If using the CLI, use the s3api or efsapi call instead
  of s3 or efs so you can use the put-object operation. For example, you use the following:
  aws s3api put-object --bucket bucketname --key path/to/folder/. Make sure that the end of
  the key name ends in a / for it to be considered a folder.
- `"HomeDirectoryType"`: The type of landing directory (folder) you want your users' home
  directory to be when they log into the server. If you set it to PATH, the user will see the
  absolute Amazon S3 bucket or EFS paths as is in their file transfer protocol clients. If
  you set it LOGICAL, you will need to provide mappings in the HomeDirectoryMappings for how
  you want to make Amazon S3 or EFS paths visible to your users.
- `"Policy"`: A scope-down policy for your user so that you can use the same IAM role
  across multiple users. This policy scopes down user access to portions of their Amazon S3
  bucket. Variables that you can use inside this policy include {Transfer:UserName},
  {Transfer:HomeDirectory}, and {Transfer:HomeBucket}.  This only applies when domain of
  ServerId is S3. Amazon EFS does not use scope-down policies. For scope-down policies,
  Amazon Web ServicesTransfer Family stores the policy as a JSON blob, instead of the Amazon
  Resource Name (ARN) of the policy. You save the policy as a JSON blob and pass it in the
  Policy argument. For an example of a scope-down policy, see Creating a scope-down policy.
  For more information, see AssumeRole in the Amazon Web Services Security Token Service API
  Reference.
- `"PosixProfile"`: Specifies the full POSIX identity, including user ID (Uid), group ID
  (Gid), and any secondary groups IDs (SecondaryGids), that controls your users' access to
  your Amazon Elastic File Systems (Amazon EFS). The POSIX permissions that are set on files
  and directories in your file system determines the level of access your users get when
  transferring files into and out of your Amazon EFS file systems.
- `"Role"`: Specifies the Amazon Resource Name (ARN) of the IAM role that controls your
  users' access to your Amazon S3 bucket or EFS file system. The policies attached to this
  role determine the level of access that you want to provide your users when transferring
  files into and out of your Amazon S3 bucket or EFS file system. The IAM role should also
  contain a trust relationship that allows the server to access your resources when servicing
  your users' transfer requests.
"""
update_user(ServerId, UserName; aws_config::AbstractAWSConfig=global_aws_config()) = transfer("UpdateUser", Dict{String, Any}("ServerId"=>ServerId, "UserName"=>UserName); aws_config=aws_config)
update_user(ServerId, UserName, params::AbstractDict{String}; aws_config::AbstractAWSConfig=global_aws_config()) = transfer("UpdateUser", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("ServerId"=>ServerId, "UserName"=>UserName), params)); aws_config=aws_config)
